# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waBotMetadata/WAWebProtobufsBotMetadata.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'waBotMetadata/WAWebProtobufsBotMetadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-waBotMetadata/WAWebProtobufsBotMetadata.proto\x12\x19WAWebProtobufsBotMetadata\x1a\x17waCommon/WACommon.proto\"\xb5\x05\n\x11\x42otPluginMetadata\x12M\n\x08provider\x18\x01 \x01(\x0e\x32;.WAWebProtobufsBotMetadata.BotPluginMetadata.SearchProvider\x12K\n\npluginType\x18\x02 \x01(\x0e\x32\x37.WAWebProtobufsBotMetadata.BotPluginMetadata.PluginType\x12\x17\n\x0fthumbnailCDNURL\x18\x03 \x01(\t\x12\x1a\n\x12profilePhotoCDNURL\x18\x04 \x01(\t\x12\x19\n\x11searchProviderURL\x18\x05 \x01(\t\x12\x16\n\x0ereferenceIndex\x18\x06 \x01(\r\x12\x1a\n\x12\x65xpectedLinksCount\x18\x07 \x01(\r\x12\x13\n\x0bsearchQuery\x18\t \x01(\t\x12\x34\n\x16parentPluginMessageKey\x18\n \x01(\x0b\x32\x14.WACommon.MessageKey\x12P\n\x0f\x64\x65precatedField\x18\x0b \x01(\x0e\x32\x37.WAWebProtobufsBotMetadata.BotPluginMetadata.PluginType\x12Q\n\x10parentPluginType\x18\x0c \x01(\x0e\x32\x37.WAWebProtobufsBotMetadata.BotPluginMetadata.PluginType\x12\x15\n\rfaviconCDNURL\x18\r \x01(\t\"7\n\nPluginType\x12\x12\n\x0eUNKNOWN_PLUGIN\x10\x00\x12\t\n\x05REELS\x10\x01\x12\n\n\x06SEARCH\x10\x02\"@\n\x0eSearchProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03\"\x9a\x01\n\x10\x42otLinkedAccount\x12N\n\x04type\x18\x01 \x01(\x0e\x32@.WAWebProtobufsBotMetadata.BotLinkedAccount.BotLinkedAccountType\"6\n\x14\x42otLinkedAccountType\x12\x1e\n\x1a\x42OT_LINKED_ACCOUNT_TYPE_1P\x10\x00\"\xf1\x01\n$BotSignatureVerificationUseCaseProof\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x64\n\x07useCase\x18\x02 \x01(\x0e\x32S.WAWebProtobufsBotMetadata.BotSignatureVerificationUseCaseProof.BotSignatureUseCase\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12\x18\n\x10\x63\x65rtificateChain\x18\x04 \x01(\x0c\"%\n\x13\x42otSignatureUseCase\x12\x0e\n\nWA_BOT_MSG\x10\x00\"\xc1\x01\n\x1b\x42otPromotionMessageMetadata\x12^\n\rpromotionType\x18\x01 \x01(\x0e\x32G.WAWebProtobufsBotMetadata.BotPromotionMessageMetadata.BotPromotionType\x12\x13\n\x0b\x62uttonTitle\x18\x02 \x01(\t\"-\n\x10\x42otPromotionType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x07\n\x03\x43\x35\x30\x10\x01\"\x9a\x02\n\x10\x42otMediaMetadata\x12\x12\n\nfileSHA256\x18\x01 \x01(\t\x12\x10\n\x08mediaKey\x18\x02 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\t\x12\x12\n\ndirectPath\x18\x04 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08mimetype\x18\x06 \x01(\t\x12T\n\x0forientationType\x18\x07 \x01(\x0e\x32;.WAWebProtobufsBotMetadata.BotMediaMetadata.OrientationType\"2\n\x0fOrientationType\x12\n\n\x06\x43\x45NTER\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03\"\xa9\x03\n\x13\x42otReminderMetadata\x12/\n\x11requestMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12M\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32=.WAWebProtobufsBotMetadata.BotReminderMetadata.ReminderAction\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14nextTriggerTimestamp\x18\x04 \x01(\x04\x12S\n\tfrequency\x18\x05 \x01(\x0e\x32@.WAWebProtobufsBotMetadata.BotReminderMetadata.ReminderFrequency\"O\n\x11ReminderFrequency\x12\x08\n\x04ONCE\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0c\n\x08\x42IWEEKLY\x10\x04\x12\x0b\n\x07MONTHLY\x10\x05\"@\n\x0eReminderAction\x12\n\n\x06NOTIFY\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPDATE\x10\x04\"\xd0\x02\n\x10\x42otModelMetadata\x12H\n\tmodelType\x18\x01 \x01(\x0e\x32\x35.WAWebProtobufsBotMetadata.BotModelMetadata.ModelType\x12Z\n\x12premiumModelStatus\x18\x02 \x01(\x0e\x32>.WAWebProtobufsBotMetadata.BotModelMetadata.PremiumModelStatus\"O\n\x12PremiumModelStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\r\n\tAVAILABLE\x10\x01\x12\x16\n\x12QUOTA_EXCEED_LIMIT\x10\x02\"E\n\tModelType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0e\n\nLLAMA_PROD\x10\x01\x12\x16\n\x12LLAMA_PROD_PREMIUM\x10\x02\"\xab\x0c\n\x1c\x42otProgressIndicatorMetadata\x12\x1b\n\x13progressDescription\x18\x01 \x01(\t\x12\x66\n\rstepsMetadata\x18\x02 \x03(\x0b\x32O.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata\x1a\x85\x0b\n\x17\x42otPlanningStepMetadata\x12\x13\n\x0bstatusTitle\x18\x01 \x01(\t\x12\x12\n\nstatusBody\x18\x02 \x01(\t\x12\x89\x01\n\x0fsourcesMetadata\x18\x03 \x03(\x0b\x32p.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourcesMetadata\x12r\n\x06status\x18\x04 \x01(\x0e\x32\x62.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.PlanningStepStatus\x12\x13\n\x0bisReasoning\x18\x05 \x01(\x08\x12\x18\n\x10isEnhancedSearch\x18\x06 \x01(\x08\x12\x80\x01\n\x08sections\x18\x07 \x03(\x0b\x32n.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningStepSectionMetadata\x1a\xc1\x02\n BotPlanningSearchSourcesMetadata\x12\x13\n\x0bsourceTitle\x18\x01 \x01(\t\x12\xa3\x01\n\x08provider\x18\x02 \x01(\x0e\x32\x90\x01.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourcesMetadata.BotPlanningSearchSourceProvider\x12\x11\n\tsourceURL\x18\x03 \x01(\t\"O\n\x1f\x42otPlanningSearchSourceProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x08\n\x04\x42ING\x10\x03\x1a\xd6\x01\n\x1e\x42otPlanningStepSectionMetadata\x12\x14\n\x0csectionTitle\x18\x01 \x01(\t\x12\x13\n\x0bsectionBody\x18\x02 \x01(\t\x12\x88\x01\n\x0fsourcesMetadata\x18\x03 \x03(\x0b\x32o.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotPlanningSearchSourceMetadata\x1a\xd2\x01\n\x1f\x42otPlanningSearchSourceMetadata\x12\r\n\x05title\x18\x01 \x01(\t\x12y\n\x08provider\x18\x02 \x01(\x0e\x32g.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata.BotPlanningStepMetadata.BotSearchSourceProvider\x12\x11\n\tsourceURL\x18\x03 \x01(\t\x12\x12\n\nfavIconURL\x18\x04 \x01(\t\"P\n\x17\x42otSearchSourceProvider\x12\x14\n\x10UNKNOWN_PROVIDER\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x08\n\x04\x42ING\x10\x03\"K\n\x12PlanningStepStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PLANNED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03\"\xaf\n\n\x15\x42otCapabilityMetadata\x12X\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0e\x32\x42.WAWebProtobufsBotMetadata.BotCapabilityMetadata.BotCapabilityType\"\xbb\t\n\x11\x42otCapabilityType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12PROGRESS_INDICATOR\x10\x01\x12\x19\n\x15RICH_RESPONSE_HEADING\x10\x02\x12\x1d\n\x19RICH_RESPONSE_NESTED_LIST\x10\x03\x12\r\n\tAI_MEMORY\x10\x04\x12 \n\x1cRICH_RESPONSE_THREAD_SURFING\x10\x05\x12\x17\n\x13RICH_RESPONSE_TABLE\x10\x06\x12\x16\n\x12RICH_RESPONSE_CODE\x10\x07\x12%\n!RICH_RESPONSE_STRUCTURED_RESPONSE\x10\x08\x12\x1e\n\x1aRICH_RESPONSE_INLINE_IMAGE\x10\t\x12#\n\x1fWA_IG_1P_PLUGIN_RANKING_CONTROL\x10\n\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_1\x10\x0b\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_2\x10\x0c\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_3\x10\r\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_4\x10\x0e\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_5\x10\x0f\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_6\x10\x10\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_7\x10\x11\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_8\x10\x12\x12$\n WA_IG_1P_PLUGIN_RANKING_UPDATE_9\x10\x13\x12%\n!WA_IG_1P_PLUGIN_RANKING_UPDATE_10\x10\x14\x12\x1d\n\x19RICH_RESPONSE_SUB_HEADING\x10\x15\x12\x1c\n\x18RICH_RESPONSE_GRID_IMAGE\x10\x16\x12\x18\n\x14\x41I_STUDIO_UGC_MEMORY\x10\x17\x12\x17\n\x13RICH_RESPONSE_LATEX\x10\x18\x12\x16\n\x12RICH_RESPONSE_MAPS\x10\x19\x12\x1e\n\x1aRICH_RESPONSE_INLINE_REELS\x10\x1a\x12\x14\n\x10\x41GENTIC_PLANNING\x10\x1b\x12\x13\n\x0f\x41\x43\x43OUNT_LINKING\x10\x1c\x12\x1c\n\x18STREAMING_DISAGGREGATION\x10\x1d\x12\x1f\n\x1bRICH_RESPONSE_GRID_IMAGE_3P\x10\x1e\x12\x1e\n\x1aRICH_RESPONSE_LATEX_INLINE\x10\x1f\x12\x0e\n\nQUERY_PLAN\x10 \x12\x15\n\x11PROACTIVE_MESSAGE\x10!\x12\"\n\x1eRICH_RESPONSE_UNIFIED_RESPONSE\x10\"\x12\x15\n\x11PROMOTION_MESSAGE\x10#\x12\x1b\n\x17SIMPLIFIED_PROFILE_PAGE\x10$\x12$\n RICH_RESPONSE_SOURCES_IN_MESSAGE\x10%\x12%\n!RICH_RESPONSE_SIDE_BY_SIDE_SURVEY\x10&\"\xb0\x01\n\x18\x42otModeSelectionMetadata\x12V\n\x04mode\x18\x01 \x03(\x0e\x32H.WAWebProtobufsBotMetadata.BotModeSelectionMetadata.BotUserSelectionMode\"<\n\x14\x42otUserSelectionMode\x12\x10\n\x0cUNKNOWN_MODE\x10\x00\x12\x12\n\x0eREASONING_MODE\x10\x01\"\xf0\x02\n\x10\x42otQuotaMetadata\x12\x64\n\x17\x62otFeatureQuotaMetadata\x18\x01 \x03(\x0b\x32\x43.WAWebProtobufsBotMetadata.BotQuotaMetadata.BotFeatureQuotaMetadata\x1a\xf5\x01\n\x17\x42otFeatureQuotaMetadata\x12g\n\x0b\x66\x65\x61tureType\x18\x01 \x01(\x0e\x32R.WAWebProtobufsBotMetadata.BotQuotaMetadata.BotFeatureQuotaMetadata.BotFeatureType\x12\x16\n\x0eremainingQuota\x18\x02 \x01(\r\x12\x1b\n\x13\x65xpirationTimestamp\x18\x03 \x01(\x04\"<\n\x0e\x42otFeatureType\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x15\n\x11REASONING_FEATURE\x10\x01\"\xac\x01\n\x12\x42otImagineMetadata\x12N\n\x0bimagineType\x18\x01 \x01(\x0e\x32\x39.WAWebProtobufsBotMetadata.BotImagineMetadata.ImagineType\"F\n\x0bImagineType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07IMAGINE\x10\x01\x12\x08\n\x04MEMU\x10\x02\x12\t\n\x05\x46LASH\x10\x03\x12\x08\n\x04\x45\x44IT\x10\x04\"\xac\x03\n\x12\x42otSourcesMetadata\x12L\n\x07sources\x18\x01 \x03(\x0b\x32;.WAWebProtobufsBotMetadata.BotSourcesMetadata.BotSourceItem\x1a\xc7\x02\n\rBotSourceItem\x12\\\n\x08provider\x18\x01 \x01(\x0e\x32J.WAWebProtobufsBotMetadata.BotSourcesMetadata.BotSourceItem.SourceProvider\x12\x17\n\x0fthumbnailCDNURL\x18\x02 \x01(\t\x12\x19\n\x11sourceProviderURL\x18\x03 \x01(\t\x12\x13\n\x0bsourceQuery\x18\x04 \x01(\t\x12\x15\n\rfaviconCDNURL\x18\x05 \x01(\t\x12\x16\n\x0e\x63itationNumber\x18\x06 \x01(\r\x12\x13\n\x0bsourceTitle\x18\x07 \x01(\t\"K\n\x0eSourceProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03\x12\t\n\x05OTHER\x10\x04\"\xa4\x01\n\x10\x42otMessageOrigin\x12N\n\x04type\x18\x01 \x01(\x0e\x32@.WAWebProtobufsBotMetadata.BotMessageOrigin.BotMessageOriginType\"@\n\x14\x42otMessageOriginType\x12(\n$BOT_MESSAGE_ORIGIN_TYPE_AI_INITIATED\x10\x00\"s\n\x11\x42otAvatarMetadata\x12\x11\n\tsentiment\x18\x01 \x01(\r\x12\x15\n\rbehaviorGraph\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\r\x12\x11\n\tintensity\x18\x04 \x01(\r\x12\x11\n\twordCount\x18\x05 \x01(\r\"\xb9\x01\n\x1a\x42otSuggestedPromptMetadata\x12\x18\n\x10suggestedPrompts\x18\x01 \x03(\t\x12\x1b\n\x13selectedPromptIndex\x18\x02 \x01(\r\x12J\n\x11promptSuggestions\x18\x03 \x01(\x0b\x32/.WAWebProtobufsBotMetadata.BotPromptSuggestions\x12\x18\n\x10selectedPromptID\x18\x04 \x01(\t\"[\n\x14\x42otPromptSuggestions\x12\x43\n\x0bsuggestions\x18\x01 \x03(\x0b\x32..WAWebProtobufsBotMetadata.BotPromptSuggestion\"7\n\x13\x42otPromptSuggestion\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x10\n\x08promptID\x18\x02 \x01(\t\"\x85\x01\n\x19\x42otLinkedAccountsMetadata\x12=\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32+.WAWebProtobufsBotMetadata.BotLinkedAccount\x12\x14\n\x0c\x61\x63\x41uthTokens\x18\x02 \x01(\x0c\x12\x13\n\x0b\x61\x63\x45rrorCode\x18\x03 \x01(\x05\"\xa5\x01\n\x11\x42otMemoryMetadata\x12<\n\naddedFacts\x18\x01 \x03(\x0b\x32(.WAWebProtobufsBotMetadata.BotMemoryFact\x12>\n\x0cremovedFacts\x18\x02 \x03(\x0b\x32(.WAWebProtobufsBotMetadata.BotMemoryFact\x12\x12\n\ndisclaimer\x18\x03 \x01(\t\"-\n\rBotMemoryFact\x12\x0c\n\x04\x66\x61\x63t\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63tID\x18\x02 \x01(\t\"s\n BotSignatureVerificationMetadata\x12O\n\x06proofs\x18\x01 \x03(\x0b\x32?.WAWebProtobufsBotMetadata.BotSignatureVerificationUseCaseProof\"\x96\x01\n\x14\x42otRenderingMetadata\x12I\n\x08keywords\x18\x01 \x03(\x0b\x32\x37.WAWebProtobufsBotMetadata.BotRenderingMetadata.Keyword\x1a\x33\n\x07Keyword\x12\r\n\x05value\x18\x01 \x01(\t\x12\x19\n\x11\x61ssociatedPrompts\x18\x02 \x03(\t\"\xc8\x01\n\x12\x42otMetricsMetadata\x12\x15\n\rdestinationID\x18\x01 \x01(\t\x12N\n\x15\x64\x65stinationEntryPoint\x18\x02 \x01(\x0e\x32/.WAWebProtobufsBotMetadata.BotMetricsEntryPoint\x12K\n\x0cthreadOrigin\x18\x03 \x01(\x0e\x32\x35.WAWebProtobufsBotMetadata.BotMetricsThreadEntryPoint\"k\n\x12\x42otSessionMetadata\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x42\n\rsessionSource\x18\x02 \x01(\x0e\x32+.WAWebProtobufsBotMetadata.BotSessionSource\"R\n\x0f\x42otMemuMetadata\x12?\n\nfaceImages\x18\x01 \x03(\x0b\x32+.WAWebProtobufsBotMetadata.BotMediaMetadata\"e\n\x18\x42otAgeCollectionMetadata\x12\x1d\n\x15\x61geCollectionEligible\x18\x01 \x01(\x08\x12*\n\"shouldTriggerAgeCollectionOnClient\x18\x02 \x01(\x08\"X\n\x18\x42otMessageOriginMetadata\x12<\n\x07origins\x18\x01 \x03(\x0b\x32+.WAWebProtobufsBotMetadata.BotMessageOrigin\"\xac\x01\n\x1a\x42otUnifiedResponseMutation\x12]\n\x0bsbsMetadata\x18\x01 \x01(\x0b\x32H.WAWebProtobufsBotMetadata.BotUnifiedResponseMutation.SideBySideMetadata\x1a/\n\x12SideBySideMetadata\x12\x19\n\x11primaryResponseID\x18\x01 \x01(\t\"\x94\x0f\n\x0b\x42otMetadata\x12\x44\n\x0e\x61vatarMetadata\x18\x01 \x01(\x0b\x32,.WAWebProtobufsBotMetadata.BotAvatarMetadata\x12\x11\n\tpersonaID\x18\x02 \x01(\t\x12\x44\n\x0epluginMetadata\x18\x03 \x01(\x0b\x32,.WAWebProtobufsBotMetadata.BotPluginMetadata\x12V\n\x17suggestedPromptMetadata\x18\x04 \x01(\x0b\x32\x35.WAWebProtobufsBotMetadata.BotSuggestedPromptMetadata\x12\x12\n\ninvokerJID\x18\x05 \x01(\t\x12\x46\n\x0fsessionMetadata\x18\x06 \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotSessionMetadata\x12@\n\x0cmemuMetadata\x18\x07 \x01(\x0b\x32*.WAWebProtobufsBotMetadata.BotMemuMetadata\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12H\n\x10reminderMetadata\x18\t \x01(\x0b\x32..WAWebProtobufsBotMetadata.BotReminderMetadata\x12\x42\n\rmodelMetadata\x18\n \x01(\x0b\x32+.WAWebProtobufsBotMetadata.BotModelMetadata\x12\x1d\n\x15messageDisclaimerText\x18\x0b \x01(\t\x12Z\n\x19progressIndicatorMetadata\x18\x0c \x01(\x0b\x32\x37.WAWebProtobufsBotMetadata.BotProgressIndicatorMetadata\x12L\n\x12\x63\x61pabilityMetadata\x18\r \x01(\x0b\x32\x30.WAWebProtobufsBotMetadata.BotCapabilityMetadata\x12\x46\n\x0fimagineMetadata\x18\x0e \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotImagineMetadata\x12\x44\n\x0ememoryMetadata\x18\x0f \x01(\x0b\x32,.WAWebProtobufsBotMetadata.BotMemoryMetadata\x12J\n\x11renderingMetadata\x18\x10 \x01(\x0b\x32/.WAWebProtobufsBotMetadata.BotRenderingMetadata\x12I\n\x12\x62otMetricsMetadata\x18\x11 \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotMetricsMetadata\x12W\n\x19\x62otLinkedAccountsMetadata\x18\x12 \x01(\x0b\x32\x34.WAWebProtobufsBotMetadata.BotLinkedAccountsMetadata\x12R\n\x1brichResponseSourcesMetadata\x18\x13 \x01(\x0b\x32-.WAWebProtobufsBotMetadata.BotSourcesMetadata\x12\x1d\n\x15\x61iConversationContext\x18\x14 \x01(\x0c\x12[\n\x1b\x62otPromotionMessageMetadata\x18\x15 \x01(\x0b\x32\x36.WAWebProtobufsBotMetadata.BotPromotionMessageMetadata\x12U\n\x18\x62otModeSelectionMetadata\x18\x16 \x01(\x0b\x32\x33.WAWebProtobufsBotMetadata.BotModeSelectionMetadata\x12\x45\n\x10\x62otQuotaMetadata\x18\x17 \x01(\x0b\x32+.WAWebProtobufsBotMetadata.BotQuotaMetadata\x12U\n\x18\x62otAgeCollectionMetadata\x18\x18 \x01(\x0b\x32\x33.WAWebProtobufsBotMetadata.BotAgeCollectionMetadata\x12#\n\x1b\x63onversationStarterPromptID\x18\x19 \x01(\t\x12\x15\n\rbotResponseID\x18\x1a \x01(\t\x12Y\n\x14verificationMetadata\x18\x1b \x01(\x0b\x32;.WAWebProtobufsBotMetadata.BotSignatureVerificationMetadata\x12V\n\x17unifiedResponseMutation\x18\x1c \x01(\x0b\x32\x35.WAWebProtobufsBotMetadata.BotUnifiedResponseMutation\x12U\n\x18\x62otMessageOriginMetadata\x18\x1d \x01(\x0b\x32\x33.WAWebProtobufsBotMetadata.BotMessageOriginMetadata*\xac\x06\n\x14\x42otMetricsEntryPoint\x12\x0b\n\x07\x46\x41VICON\x10\x01\x12\x0c\n\x08\x43HATLIST\x10\x02\x12#\n\x1f\x41ISEARCH_NULL_STATE_PAPER_PLANE\x10\x03\x12\"\n\x1e\x41ISEARCH_NULL_STATE_SUGGESTION\x10\x04\x12\"\n\x1e\x41ISEARCH_TYPE_AHEAD_SUGGESTION\x10\x05\x12#\n\x1f\x41ISEARCH_TYPE_AHEAD_PAPER_PLANE\x10\x06\x12\'\n#AISEARCH_TYPE_AHEAD_RESULT_CHATLIST\x10\x07\x12\'\n#AISEARCH_TYPE_AHEAD_RESULT_MESSAGES\x10\x08\x12\x16\n\x12\x41IVOICE_SEARCH_BAR\x10\t\x12\x13\n\x0f\x41IVOICE_FAVICON\x10\n\x12\x0c\n\x08\x41ISTUDIO\x10\x0b\x12\x0c\n\x08\x44\x45\x45PLINK\x10\x0c\x12\x10\n\x0cNOTIFICATION\x10\r\x12\x1a\n\x16PROFILE_MESSAGE_BUTTON\x10\x0e\x12\x0b\n\x07\x46ORWARD\x10\x0f\x12\x10\n\x0c\x41PP_SHORTCUT\x10\x10\x12\r\n\tFF_FAMILY\x10\x11\x12\n\n\x06\x41I_TAB\x10\x12\x12\x0b\n\x07\x41I_HOME\x10\x13\x12\x19\n\x15\x41I_DEEPLINK_IMMERSIVE\x10\x14\x12\x0f\n\x0b\x41I_DEEPLINK\x10\x15\x12#\n\x1fMETA_AI_CHAT_SHORTCUT_AI_STUDIO\x10\x16\x12\x1f\n\x1bUGC_CHAT_SHORTCUT_AI_STUDIO\x10\x17\x12\x16\n\x12NEW_CHAT_AI_STUDIO\x10\x18\x12 \n\x1c\x41IVOICE_FAVICON_CALL_HISTORY\x10\x19\x12\x1c\n\x18\x41SK_META_AI_CONTEXT_MENU\x10\x1a\x12!\n\x1d\x41SK_META_AI_CONTEXT_MENU_1ON1\x10\x1b\x12\"\n\x1e\x41SK_META_AI_CONTEXT_MENU_GROUP\x10\x1c\x12\x17\n\x13INVOKE_META_AI_1ON1\x10\x1d\x12\x18\n\x14INVOKE_META_AI_GROUP\x10\x1e\x12\x13\n\x0fMETA_AI_FORWARD\x10\x1f*\xa2\x01\n\x1a\x42otMetricsThreadEntryPoint\x12\x11\n\rAI_TAB_THREAD\x10\x01\x12\x12\n\x0e\x41I_HOME_THREAD\x10\x02\x12 \n\x1c\x41I_DEEPLINK_IMMERSIVE_THREAD\x10\x03\x12\x16\n\x12\x41I_DEEPLINK_THREAD\x10\x04\x12#\n\x1f\x41SK_META_AI_CONTEXT_MENU_THREAD\x10\x05*}\n\x10\x42otSessionSource\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nNULL_STATE\x10\x01\x12\r\n\tTYPEAHEAD\x10\x02\x12\x0e\n\nUSER_INPUT\x10\x03\x12\r\n\tEMU_FLASH\x10\x04\x12\x16\n\x12\x45MU_FLASH_FOLLOWUP\x10\x05\x12\t\n\x05VOICE\x10\x06\x42)Z\'go.mau.fi/whatsmeow/proto/waBotMetadata')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waBotMetadata.WAWebProtobufsBotMetadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waBotMetadata'
  _globals['_BOTMETRICSENTRYPOINT']._serialized_start=10465
  _globals['_BOTMETRICSENTRYPOINT']._serialized_end=11277
  _globals['_BOTMETRICSTHREADENTRYPOINT']._serialized_start=11280
  _globals['_BOTMETRICSTHREADENTRYPOINT']._serialized_end=11442
  _globals['_BOTSESSIONSOURCE']._serialized_start=11444
  _globals['_BOTSESSIONSOURCE']._serialized_end=11569
  _globals['_BOTPLUGINMETADATA']._serialized_start=102
  _globals['_BOTPLUGINMETADATA']._serialized_end=795
  _globals['_BOTPLUGINMETADATA_PLUGINTYPE']._serialized_start=674
  _globals['_BOTPLUGINMETADATA_PLUGINTYPE']._serialized_end=729
  _globals['_BOTPLUGINMETADATA_SEARCHPROVIDER']._serialized_start=731
  _globals['_BOTPLUGINMETADATA_SEARCHPROVIDER']._serialized_end=795
  _globals['_BOTLINKEDACCOUNT']._serialized_start=798
  _globals['_BOTLINKEDACCOUNT']._serialized_end=952
  _globals['_BOTLINKEDACCOUNT_BOTLINKEDACCOUNTTYPE']._serialized_start=898
  _globals['_BOTLINKEDACCOUNT_BOTLINKEDACCOUNTTYPE']._serialized_end=952
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF']._serialized_start=955
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF']._serialized_end=1196
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF_BOTSIGNATUREUSECASE']._serialized_start=1159
  _globals['_BOTSIGNATUREVERIFICATIONUSECASEPROOF_BOTSIGNATUREUSECASE']._serialized_end=1196
  _globals['_BOTPROMOTIONMESSAGEMETADATA']._serialized_start=1199
  _globals['_BOTPROMOTIONMESSAGEMETADATA']._serialized_end=1392
  _globals['_BOTPROMOTIONMESSAGEMETADATA_BOTPROMOTIONTYPE']._serialized_start=1347
  _globals['_BOTPROMOTIONMESSAGEMETADATA_BOTPROMOTIONTYPE']._serialized_end=1392
  _globals['_BOTMEDIAMETADATA']._serialized_start=1395
  _globals['_BOTMEDIAMETADATA']._serialized_end=1677
  _globals['_BOTMEDIAMETADATA_ORIENTATIONTYPE']._serialized_start=1627
  _globals['_BOTMEDIAMETADATA_ORIENTATIONTYPE']._serialized_end=1677
  _globals['_BOTREMINDERMETADATA']._serialized_start=1680
  _globals['_BOTREMINDERMETADATA']._serialized_end=2105
  _globals['_BOTREMINDERMETADATA_REMINDERFREQUENCY']._serialized_start=1960
  _globals['_BOTREMINDERMETADATA_REMINDERFREQUENCY']._serialized_end=2039
  _globals['_BOTREMINDERMETADATA_REMINDERACTION']._serialized_start=2041
  _globals['_BOTREMINDERMETADATA_REMINDERACTION']._serialized_end=2105
  _globals['_BOTMODELMETADATA']._serialized_start=2108
  _globals['_BOTMODELMETADATA']._serialized_end=2444
  _globals['_BOTMODELMETADATA_PREMIUMMODELSTATUS']._serialized_start=2294
  _globals['_BOTMODELMETADATA_PREMIUMMODELSTATUS']._serialized_end=2373
  _globals['_BOTMODELMETADATA_MODELTYPE']._serialized_start=2375
  _globals['_BOTMODELMETADATA_MODELTYPE']._serialized_end=2444
  _globals['_BOTPROGRESSINDICATORMETADATA']._serialized_start=2447
  _globals['_BOTPROGRESSINDICATORMETADATA']._serialized_end=4026
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA']._serialized_start=2613
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA']._serialized_end=4026
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA']._serialized_start=3116
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA']._serialized_end=3437
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA_BOTPLANNINGSEARCHSOURCEPROVIDER']._serialized_start=3358
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCESMETADATA_BOTPLANNINGSEARCHSOURCEPROVIDER']._serialized_end=3437
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSTEPSECTIONMETADATA']._serialized_start=3440
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSTEPSECTIONMETADATA']._serialized_end=3654
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCEMETADATA']._serialized_start=3657
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTPLANNINGSEARCHSOURCEMETADATA']._serialized_end=3867
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTSEARCHSOURCEPROVIDER']._serialized_start=3869
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_BOTSEARCHSOURCEPROVIDER']._serialized_end=3949
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_PLANNINGSTEPSTATUS']._serialized_start=3951
  _globals['_BOTPROGRESSINDICATORMETADATA_BOTPLANNINGSTEPMETADATA_PLANNINGSTEPSTATUS']._serialized_end=4026
  _globals['_BOTCAPABILITYMETADATA']._serialized_start=4029
  _globals['_BOTCAPABILITYMETADATA']._serialized_end=5356
  _globals['_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE']._serialized_start=4145
  _globals['_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE']._serialized_end=5356
  _globals['_BOTMODESELECTIONMETADATA']._serialized_start=5359
  _globals['_BOTMODESELECTIONMETADATA']._serialized_end=5535
  _globals['_BOTMODESELECTIONMETADATA_BOTUSERSELECTIONMODE']._serialized_start=5475
  _globals['_BOTMODESELECTIONMETADATA_BOTUSERSELECTIONMODE']._serialized_end=5535
  _globals['_BOTQUOTAMETADATA']._serialized_start=5538
  _globals['_BOTQUOTAMETADATA']._serialized_end=5906
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA']._serialized_start=5661
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA']._serialized_end=5906
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA_BOTFEATURETYPE']._serialized_start=5846
  _globals['_BOTQUOTAMETADATA_BOTFEATUREQUOTAMETADATA_BOTFEATURETYPE']._serialized_end=5906
  _globals['_BOTIMAGINEMETADATA']._serialized_start=5909
  _globals['_BOTIMAGINEMETADATA']._serialized_end=6081
  _globals['_BOTIMAGINEMETADATA_IMAGINETYPE']._serialized_start=6011
  _globals['_BOTIMAGINEMETADATA_IMAGINETYPE']._serialized_end=6081
  _globals['_BOTSOURCESMETADATA']._serialized_start=6084
  _globals['_BOTSOURCESMETADATA']._serialized_end=6512
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM']._serialized_start=6185
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM']._serialized_end=6512
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM_SOURCEPROVIDER']._serialized_start=6437
  _globals['_BOTSOURCESMETADATA_BOTSOURCEITEM_SOURCEPROVIDER']._serialized_end=6512
  _globals['_BOTMESSAGEORIGIN']._serialized_start=6515
  _globals['_BOTMESSAGEORIGIN']._serialized_end=6679
  _globals['_BOTMESSAGEORIGIN_BOTMESSAGEORIGINTYPE']._serialized_start=6615
  _globals['_BOTMESSAGEORIGIN_BOTMESSAGEORIGINTYPE']._serialized_end=6679
  _globals['_BOTAVATARMETADATA']._serialized_start=6681
  _globals['_BOTAVATARMETADATA']._serialized_end=6796
  _globals['_BOTSUGGESTEDPROMPTMETADATA']._serialized_start=6799
  _globals['_BOTSUGGESTEDPROMPTMETADATA']._serialized_end=6984
  _globals['_BOTPROMPTSUGGESTIONS']._serialized_start=6986
  _globals['_BOTPROMPTSUGGESTIONS']._serialized_end=7077
  _globals['_BOTPROMPTSUGGESTION']._serialized_start=7079
  _globals['_BOTPROMPTSUGGESTION']._serialized_end=7134
  _globals['_BOTLINKEDACCOUNTSMETADATA']._serialized_start=7137
  _globals['_BOTLINKEDACCOUNTSMETADATA']._serialized_end=7270
  _globals['_BOTMEMORYMETADATA']._serialized_start=7273
  _globals['_BOTMEMORYMETADATA']._serialized_end=7438
  _globals['_BOTMEMORYFACT']._serialized_start=7440
  _globals['_BOTMEMORYFACT']._serialized_end=7485
  _globals['_BOTSIGNATUREVERIFICATIONMETADATA']._serialized_start=7487
  _globals['_BOTSIGNATUREVERIFICATIONMETADATA']._serialized_end=7602
  _globals['_BOTRENDERINGMETADATA']._serialized_start=7605
  _globals['_BOTRENDERINGMETADATA']._serialized_end=7755
  _globals['_BOTRENDERINGMETADATA_KEYWORD']._serialized_start=7704
  _globals['_BOTRENDERINGMETADATA_KEYWORD']._serialized_end=7755
  _globals['_BOTMETRICSMETADATA']._serialized_start=7758
  _globals['_BOTMETRICSMETADATA']._serialized_end=7958
  _globals['_BOTSESSIONMETADATA']._serialized_start=7960
  _globals['_BOTSESSIONMETADATA']._serialized_end=8067
  _globals['_BOTMEMUMETADATA']._serialized_start=8069
  _globals['_BOTMEMUMETADATA']._serialized_end=8151
  _globals['_BOTAGECOLLECTIONMETADATA']._serialized_start=8153
  _globals['_BOTAGECOLLECTIONMETADATA']._serialized_end=8254
  _globals['_BOTMESSAGEORIGINMETADATA']._serialized_start=8256
  _globals['_BOTMESSAGEORIGINMETADATA']._serialized_end=8344
  _globals['_BOTUNIFIEDRESPONSEMUTATION']._serialized_start=8347
  _globals['_BOTUNIFIEDRESPONSEMUTATION']._serialized_end=8519
  _globals['_BOTUNIFIEDRESPONSEMUTATION_SIDEBYSIDEMETADATA']._serialized_start=8472
  _globals['_BOTUNIFIEDRESPONSEMUTATION_SIDEBYSIDEMETADATA']._serialized_end=8519
  _globals['_BOTMETADATA']._serialized_start=8522
  _globals['_BOTMETADATA']._serialized_end=10462
# @@protoc_insertion_point(module_scope)
