# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waSyncdSnapshotRecovery/WAWebProtobufsSyncdSnapshotRecovery.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'waSyncdSnapshotRecovery/WAWebProtobufsSyncdSnapshotRecovery.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waSyncAction import WASyncAction_pb2 as waSyncAction_dot_WASyncAction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAwaSyncdSnapshotRecovery/WAWebProtobufsSyncdSnapshotRecovery.proto\x12#WAWebProtobufsSyncdSnapshotRecovery\x1a\x1fwaSyncAction/WASyncAction.proto\"\xe1\x01\n\x15SyncdSnapshotRecovery\x12\x42\n\x07version\x18\x01 \x01(\x0b\x32\x31.WAWebProtobufsSyncdSnapshotRecovery.SyncdVersion\x12\x16\n\x0e\x63ollectionName\x18\x02 \x01(\t\x12R\n\x0fmutationRecords\x18\x03 \x03(\x0b\x32\x39.WAWebProtobufsSyncdSnapshotRecovery.SyncdPlainTextRecord\x12\x18\n\x10\x63ollectionLthash\x18\x04 \x01(\x0c\"_\n\x14SyncdPlainTextRecord\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.WASyncAction.SyncActionData\x12\r\n\x05keyID\x18\x02 \x01(\x0c\x12\x0b\n\x03mac\x18\x03 \x01(\x0c\"\x1f\n\x0cSyncdVersion\x12\x0f\n\x07version\x18\x01 \x01(\x04\x42\x33Z1go.mau.fi/whatsmeow/proto/waSyncdSnapshotRecovery')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waSyncdSnapshotRecovery.WAWebProtobufsSyncdSnapshotRecovery_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1go.mau.fi/whatsmeow/proto/waSyncdSnapshotRecovery'
  _globals['_SYNCDSNAPSHOTRECOVERY']._serialized_start=140
  _globals['_SYNCDSNAPSHOTRECOVERY']._serialized_end=365
  _globals['_SYNCDPLAINTEXTRECORD']._serialized_start=367
  _globals['_SYNCDPLAINTEXTRECORD']._serialized_end=462
  _globals['_SYNCDVERSION']._serialized_start=464
  _globals['_SYNCDVERSION']._serialized_end=495
# @@protoc_insertion_point(module_scope)
