"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtendedTextMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TEXT_FIELD_NUMBER: builtins.int
        CONTEXTINFO_FIELD_NUMBER: builtins.int
        text: builtins.str
        @property
        def contextInfo(self) -> global___Message.ContextInfo: ...
        def __init__(
            self,
            *,
            text: builtins.str | None = ...,
            contextInfo: global___Message.ContextInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["contextInfo", b"contextInfo", "text", b"text"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["contextInfo", b"contextInfo", "text", b"text"]) -> None: ...

    @typing.final
    class ContextInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STANZAID_FIELD_NUMBER: builtins.int
        PARTICIPANT_FIELD_NUMBER: builtins.int
        QUOTEDMESSAGE_FIELD_NUMBER: builtins.int
        stanzaID: builtins.str
        participant: builtins.str
        @property
        def quotedMessage(self) -> global___Message: ...
        def __init__(
            self,
            *,
            stanzaID: builtins.str | None = ...,
            participant: builtins.str | None = ...,
            quotedMessage: global___Message | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["participant", b"participant", "quotedMessage", b"quotedMessage", "stanzaID", b"stanzaID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["participant", b"participant", "quotedMessage", b"quotedMessage", "stanzaID", b"stanzaID"]) -> None: ...

    CONVERSATION_FIELD_NUMBER: builtins.int
    EXTENDEDTEXTMESSAGE_FIELD_NUMBER: builtins.int
    MESSAGECONTEXTINFO_FIELD_NUMBER: builtins.int
    conversation: builtins.str
    @property
    def extendedTextMessage(self) -> global___Message.ExtendedTextMessage: ...
    @property
    def messageContextInfo(self) -> global___MessageContextInfo: ...
    def __init__(
        self,
        *,
        conversation: builtins.str | None = ...,
        extendedTextMessage: global___Message.ExtendedTextMessage | None = ...,
        messageContextInfo: global___MessageContextInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conversation", b"conversation", "extendedTextMessage", b"extendedTextMessage", "messageContextInfo", b"messageContextInfo"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conversation", b"conversation", "extendedTextMessage", b"extendedTextMessage", "messageContextInfo", b"messageContextInfo"]) -> None: ...

global___Message = Message

@typing.final
class MessageContextInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGESECRET_FIELD_NUMBER: builtins.int
    messageSecret: builtins.bytes
    def __init__(
        self,
        *,
        messageSecret: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["messageSecret", b"messageSecret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["messageSecret", b"messageSecret"]) -> None: ...

global___MessageContextInfo = MessageContextInfo
