"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import instamadilloAddMessage.InstamadilloAddMessage_pb2
import instamadilloDeleteMessage.InstamadilloDeleteMessage_pb2
import instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PayloadCreator:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PayloadCreatorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PayloadCreator.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PAYLOAD_CREATOR_UNSPECIFIED: _PayloadCreator.ValueType  # 0
    PAYLOAD_CREATOR_IGIOS: _PayloadCreator.ValueType  # 1
    PAYLOAD_CREATOR_IG4A: _PayloadCreator.ValueType  # 2
    PAYLOAD_CREATOR_WWW: _PayloadCreator.ValueType  # 3
    PAYLOAD_CREATOR_IGLITE: _PayloadCreator.ValueType  # 4

class PayloadCreator(_PayloadCreator, metaclass=_PayloadCreatorEnumTypeWrapper): ...

PAYLOAD_CREATOR_UNSPECIFIED: PayloadCreator.ValueType  # 0
PAYLOAD_CREATOR_IGIOS: PayloadCreator.ValueType  # 1
PAYLOAD_CREATOR_IG4A: PayloadCreator.ValueType  # 2
PAYLOAD_CREATOR_WWW: PayloadCreator.ValueType  # 3
PAYLOAD_CREATOR_IGLITE: PayloadCreator.ValueType  # 4
global___PayloadCreator = PayloadCreator

@typing.final
class TransportPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADD_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    SUPPLEMENT_FIELD_NUMBER: builtins.int
    FRANKING_FIELD_NUMBER: builtins.int
    OPENEB_FIELD_NUMBER: builtins.int
    ISE2EEATTRIBUTED_FIELD_NUMBER: builtins.int
    PAYLOADCREATOR_FIELD_NUMBER: builtins.int
    openEb: builtins.bool
    isE2EeAttributed: builtins.bool
    payloadCreator: global___PayloadCreator.ValueType
    @property
    def add(self) -> instamadilloAddMessage.InstamadilloAddMessage_pb2.AddMessagePayload: ...
    @property
    def delete(self) -> instamadilloDeleteMessage.InstamadilloDeleteMessage_pb2.DeleteMessagePayload: ...
    @property
    def supplement(self) -> instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2.SupplementMessagePayload: ...
    @property
    def franking(self) -> global___Franking: ...
    def __init__(
        self,
        *,
        add: instamadilloAddMessage.InstamadilloAddMessage_pb2.AddMessagePayload | None = ...,
        delete: instamadilloDeleteMessage.InstamadilloDeleteMessage_pb2.DeleteMessagePayload | None = ...,
        supplement: instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2.SupplementMessagePayload | None = ...,
        franking: global___Franking | None = ...,
        openEb: builtins.bool | None = ...,
        isE2EeAttributed: builtins.bool | None = ...,
        payloadCreator: global___PayloadCreator.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["add", b"add", "delete", b"delete", "franking", b"franking", "isE2EeAttributed", b"isE2EeAttributed", "openEb", b"openEb", "payloadCreator", b"payloadCreator", "supplement", b"supplement", "transportPayload", b"transportPayload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["add", b"add", "delete", b"delete", "franking", b"franking", "isE2EeAttributed", b"isE2EeAttributed", "openEb", b"openEb", "payloadCreator", b"payloadCreator", "supplement", b"supplement", "transportPayload", b"transportPayload"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["transportPayload", b"transportPayload"]) -> typing.Literal["add", "delete", "supplement"] | None: ...

global___TransportPayload = TransportPayload

@typing.final
class Franking(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRANKINGKEY_FIELD_NUMBER: builtins.int
    FRANKINGVERSION_FIELD_NUMBER: builtins.int
    frankingKey: builtins.bytes
    frankingVersion: builtins.int
    def __init__(
        self,
        *,
        frankingKey: builtins.bytes | None = ...,
        frankingVersion: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["frankingKey", b"frankingKey", "frankingVersion", b"frankingVersion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["frankingKey", b"frankingKey", "frankingVersion", b"frankingVersion"]) -> None: ...

global___Franking = Franking
