# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloTransportPayload/InstamadilloTransportPayload.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloTransportPayload/InstamadilloTransportPayload.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloAddMessage import InstamadilloAddMessage_pb2 as instamadilloAddMessage_dot_InstamadilloAddMessage__pb2
from instamadilloDeleteMessage import InstamadilloDeleteMessage_pb2 as instamadilloDeleteMessage_dot_InstamadilloDeleteMessage__pb2
from instamadilloSupplementMessage import InstamadilloSupplementMessage_pb2 as instamadilloSupplementMessage_dot_InstamadilloSupplementMessage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?instamadilloTransportPayload/InstamadilloTransportPayload.proto\x12\x1cInstamadilloTransportPayload\x1a\x33instamadilloAddMessage/InstamadilloAddMessage.proto\x1a\x39instamadilloDeleteMessage/InstamadilloDeleteMessage.proto\x1a\x41instamadilloSupplementMessage/InstamadilloSupplementMessage.proto\"\x9c\x03\n\x10TransportPayload\x12\x38\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32).InstamadilloAddMessage.AddMessagePayloadH\x00\x12\x41\n\x06\x64\x65lete\x18\x02 \x01(\x0b\x32/.InstamadilloDeleteMessage.DeleteMessagePayloadH\x00\x12M\n\nsupplement\x18\x03 \x01(\x0b\x32\x37.InstamadilloSupplementMessage.SupplementMessagePayloadH\x00\x12\x38\n\x08\x66ranking\x18\x04 \x01(\x0b\x32&.InstamadilloTransportPayload.Franking\x12\x0e\n\x06openEb\x18\x05 \x01(\x08\x12\x18\n\x10isE2EeAttributed\x18\x06 \x01(\x08\x12\x44\n\x0epayloadCreator\x18\x07 \x01(\x0e\x32,.InstamadilloTransportPayload.PayloadCreatorB\x12\n\x10transportPayload\"8\n\x08\x46ranking\x12\x13\n\x0b\x66rankingKey\x18\x01 \x01(\x0c\x12\x17\n\x0f\x66rankingVersion\x18\x02 \x01(\x05*\x9b\x01\n\x0ePayloadCreator\x12\x1f\n\x1bPAYLOAD_CREATOR_UNSPECIFIED\x10\x00\x12\x19\n\x15PAYLOAD_CREATOR_IGIOS\x10\x01\x12\x18\n\x14PAYLOAD_CREATOR_IG4A\x10\x02\x12\x17\n\x13PAYLOAD_CREATOR_WWW\x10\x03\x12\x1a\n\x16PAYLOAD_CREATOR_IGLITE\x10\x04\x42\x38Z6go.mau.fi/whatsmeow/proto/instamadilloTransportPayload')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloTransportPayload.InstamadilloTransportPayload_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6go.mau.fi/whatsmeow/proto/instamadilloTransportPayload'
  _globals['_PAYLOADCREATOR']._serialized_start=750
  _globals['_PAYLOADCREATOR']._serialized_end=905
  _globals['_TRANSPORTPAYLOAD']._serialized_start=277
  _globals['_TRANSPORTPAYLOAD']._serialized_end=689
  _globals['_FRANKING']._serialized_start=691
  _globals['_FRANKING']._serialized_end=747
# @@protoc_insertion_point(module_scope)
