# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloSupplementMessage/InstamadilloSupplementMessage.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloSupplementMessage/InstamadilloSupplementMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAinstamadilloSupplementMessage/InstamadilloSupplementMessage.proto\x12\x1dInstamadilloSupplementMessage\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"\xe7\x01\n\x18SupplementMessagePayload\x12\x19\n\x11targetMessageOtid\x18\x01 \x01(\t\x12&\n\x1euniquingKeyForSupplementalData\x18\x02 \x01(\t\x12H\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x37.InstamadilloSupplementMessage.SupplementMessageContent\x12$\n\x1ctargetMessageWaServerTimeSec\x18\x04 \x01(\t\x12\x18\n\x10targetWaThreadID\x18\x05 \x01(\t\"\xe8\x03\n\x18SupplementMessageContent\x12;\n\x08reaction\x18\x01 \x01(\x0b\x32\'.InstamadilloSupplementMessage.ReactionH\x00\x12\x41\n\x0b\x63ontentView\x18\x02 \x01(\x0b\x32*.InstamadilloSupplementMessage.ContentViewH\x00\x12;\n\x08\x65\x64itText\x18\x03 \x01(\x0b\x32\'.InstamadilloSupplementMessage.EditTextH\x00\x12\x45\n\rmediaReaction\x18\x04 \x01(\x0b\x32,.InstamadilloSupplementMessage.MediaReactionH\x00\x12[\n\x18originalTransportPayload\x18\x05 \x01(\x0b\x32\x37.InstamadilloSupplementMessage.OriginalTransportPayloadH\x00\x12O\n\x12mediaInterventions\x18\x06 \x01(\x0b\x32\x31.InstamadilloSupplementMessage.MediaInterventionsH\x00\x42\x1a\n\x18supplementMessageContent\"[\n\rMediaReaction\x12\x0f\n\x07mediaID\x18\x01 \x01(\t\x12\x39\n\x08reaction\x18\x02 \x01(\x0b\x32\'.InstamadilloSupplementMessage.Reaction\"v\n\x08Reaction\x12\x14\n\x0creactionType\x18\x01 \x01(\t\x12\x16\n\x0ereactionStatus\x18\x02 \x01(\t\x12\r\n\x05\x65moji\x18\x03 \x01(\t\x12\x16\n\x0esuperReactType\x18\x04 \x01(\t\x12\x15\n\ractionLogOtid\x18\x05 \x01(\t\"h\n\x0b\x43ontentView\x12\x0c\n\x04seen\x18\x01 \x01(\x08\x12\x15\n\rscreenshotted\x18\x02 \x01(\x08\x12\x10\n\x08replayed\x18\x03 \x01(\x08\x12\x10\n\x08mimetype\x18\x04 \x01(\t\x12\x10\n\x08objectID\x18\x05 \x01(\t\"1\n\x08\x45\x64itText\x12\x12\n\nnewContent\x18\x01 \x01(\t\x12\x11\n\teditCount\x18\x02 \x01(\x05\"<\n\x18OriginalTransportPayload\x12 \n\x18originalTransportPayload\x18\x01 \x01(\x0c\"r\n\x12MediaInterventions\x12\x0f\n\x07mediaID\x18\x01 \x01(\t\x12K\n\x10interventionType\x18\x02 \x01(\x0e\x32\x31.InstamadilloCoreTypeMedia.Media.InterventionTypeB9Z7go.mau.fi/whatsmeow/proto/instamadilloSupplementMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloSupplementMessage.InstamadilloSupplementMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7go.mau.fi/whatsmeow/proto/instamadilloSupplementMessage'
  _globals['_SUPPLEMENTMESSAGEPAYLOAD']._serialized_start=160
  _globals['_SUPPLEMENTMESSAGEPAYLOAD']._serialized_end=391
  _globals['_SUPPLEMENTMESSAGECONTENT']._serialized_start=394
  _globals['_SUPPLEMENTMESSAGECONTENT']._serialized_end=882
  _globals['_MEDIAREACTION']._serialized_start=884
  _globals['_MEDIAREACTION']._serialized_end=975
  _globals['_REACTION']._serialized_start=977
  _globals['_REACTION']._serialized_end=1095
  _globals['_CONTENTVIEW']._serialized_start=1097
  _globals['_CONTENTVIEW']._serialized_end=1201
  _globals['_EDITTEXT']._serialized_start=1203
  _globals['_EDITTEXT']._serialized_end=1252
  _globals['_ORIGINALTRANSPORTPAYLOAD']._serialized_start=1254
  _globals['_ORIGINALTRANSPORTPAYLOAD']._serialized_end=1314
  _globals['_MEDIAINTERVENTIONS']._serialized_start=1316
  _globals['_MEDIAINTERVENTIONS']._serialized_end=1430
# @@protoc_insertion_point(module_scope)
