# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeActionLog/InstamadilloCoreTypeActionLog.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeActionLog/InstamadilloCoreTypeActionLog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAinstamadilloCoreTypeActionLog/InstamadilloCoreTypeActionLog.proto\x12\x1dInstamadilloCoreTypeActionLog\"n\n\tActionLog\x12M\n\x11\x61\x63tionLogReaction\x18\x01 \x01(\x0b\x32\x30.InstamadilloCoreTypeActionLog.ActionLogReactionH\x00\x42\x12\n\x10\x61\x63tionLogSubtype\")\n\x11\x41\x63tionLogReaction\x12\x14\n\x0c\x65mojiUnicode\x18\x01 \x01(\tB9Z7go.mau.fi/whatsmeow/proto/instamadilloCoreTypeActionLog')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeActionLog.InstamadilloCoreTypeActionLog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7go.mau.fi/whatsmeow/proto/instamadilloCoreTypeActionLog'
  _globals['_ACTIONLOG']._serialized_start=100
  _globals['_ACTIONLOG']._serialized_end=210
  _globals['_ACTIONLOGREACTION']._serialized_start=212
  _globals['_ACTIONLOGREACTION']._serialized_end=253
# @@protoc_insertion_point(module_scope)
