"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActionLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONLOGREACTION_FIELD_NUMBER: builtins.int
    @property
    def actionLogReaction(self) -> global___ActionLogReaction: ...
    def __init__(
        self,
        *,
        actionLogReaction: global___ActionLogReaction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["actionLogReaction", b"actionLogReaction", "actionLogSubtype", b"actionLogSubtype"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["actionLogReaction", b"actionLogReaction", "actionLogSubtype", b"actionLogSubtype"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["actionLogSubtype", b"actionLogSubtype"]) -> typing.Literal["actionLogReaction"] | None: ...

global___ActionLog = ActionLog

@typing.final
class ActionLogReaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMOJIUNICODE_FIELD_NUMBER: builtins.int
    emojiUnicode: builtins.str
    def __init__(
        self,
        *,
        emojiUnicode: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["emojiUnicode", b"emojiUnicode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["emojiUnicode", b"emojiUnicode"]) -> None: ...

global___ActionLogReaction = ActionLogReaction
