# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloAddMessage/InstamadilloAddMessage.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloAddMessage/InstamadilloAddMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeActionLog import InstamadilloCoreTypeActionLog_pb2 as instamadilloCoreTypeActionLog_dot_InstamadilloCoreTypeActionLog__pb2
from instamadilloCoreTypeAdminMessage import InstamadilloCoreTypeAdminMessage_pb2 as instamadilloCoreTypeAdminMessage_dot_InstamadilloCoreTypeAdminMessage__pb2
from instamadilloCoreTypeCollection import InstamadilloCoreTypeCollection_pb2 as instamadilloCoreTypeCollection_dot_InstamadilloCoreTypeCollection__pb2
from instamadilloCoreTypeLink import InstamadilloCoreTypeLink_pb2 as instamadilloCoreTypeLink_dot_InstamadilloCoreTypeLink__pb2
from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2
from instamadilloCoreTypeText import InstamadilloCoreTypeText_pb2 as instamadilloCoreTypeText_dot_InstamadilloCoreTypeText__pb2
from instamadilloXmaContentRef import InstamadilloXmaContentRef_pb2 as instamadilloXmaContentRef_dot_InstamadilloXmaContentRef__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3instamadilloAddMessage/InstamadilloAddMessage.proto\x12\x16InstamadilloAddMessage\x1a\x41instamadilloCoreTypeActionLog/InstamadilloCoreTypeActionLog.proto\x1aGinstamadilloCoreTypeAdminMessage/InstamadilloCoreTypeAdminMessage.proto\x1a\x43instamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto\x1a\x37instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\x1a\x37instamadilloCoreTypeText/InstamadilloCoreTypeText.proto\x1a\x39instamadilloXmaContentRef/InstamadilloXmaContentRef.proto\"\x8d\x01\n\x11\x41\x64\x64MessagePayload\x12:\n\x07\x63ontent\x18\x01 \x01(\x0b\x32).InstamadilloAddMessage.AddMessageContent\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.InstamadilloAddMessage.AddMessageMetadata\"\xb4\x04\n\x11\x41\x64\x64MessageContent\x12.\n\x04text\x18\x01 \x01(\x0b\x32\x1e.InstamadilloCoreTypeText.TextH\x00\x12,\n\x04like\x18\x02 \x01(\x0b\x32\x1c.InstamadilloAddMessage.LikeH\x00\x12.\n\x04link\x18\x03 \x01(\x0b\x32\x1e.InstamadilloCoreTypeLink.LinkH\x00\x12\x44\n\x10receiverFetchXma\x18\x04 \x01(\x0b\x32(.InstamadilloAddMessage.ReceiverFetchXmaH\x00\x12\x31\n\x05media\x18\x05 \x01(\x0b\x32 .InstamadilloCoreTypeMedia.MediaH\x00\x12:\n\x0bplaceholder\x18\x06 \x01(\x0b\x32#.InstamadilloAddMessage.PlaceholderH\x00\x12@\n\ncollection\x18\x07 \x01(\x0b\x32*.InstamadilloCoreTypeCollection.CollectionH\x00\x12\x46\n\x0c\x61\x64minMessage\x18\x08 \x01(\x0b\x32..InstamadilloCoreTypeAdminMessage.AdminMessageH\x00\x12=\n\tactionLog\x18\t \x01(\x0b\x32(.InstamadilloCoreTypeActionLog.ActionLogH\x00\x42\x13\n\x11\x61\x64\x64MessageContent\"\xbe\x02\n\x12\x41\x64\x64MessageMetadata\x12\x14\n\x0csendSilently\x18\x01 \x01(\x08\x12\x42\n\x10privateReplyInfo\x18\x02 \x01(\x0b\x32(.InstamadilloAddMessage.PrivateReplyInfo\x12\x42\n\x10repliedToMessage\x18\x03 \x01(\x0b\x32(.InstamadilloAddMessage.RepliedToMessage\x12\x42\n\x10\x66orwardingParams\x18\x04 \x01(\x0b\x32(.InstamadilloAddMessage.ForwardingParams\x12\x46\n\x12\x65phemeralityParams\x18\x05 \x01(\x0b\x32*.InstamadilloAddMessage.EphemeralityParams\"\xd2\x01\n\x10RepliedToMessage\x12\x1c\n\x14repliedToMessageOtid\x18\x01 \x01(\t\x12\'\n\x1frepliedToMessageWaServerTimeSec\x18\x02 \x01(\t\x12(\n repliedToMessageCollectionItemID\x18\x03 \x01(\t\x12M\n\x0comMicroSecTS\x18\x04 \x01(\x0b\x32\x37.InstamadilloAddMessage.OpenMessageMicroSecondTimestamp\"P\n\x1fOpenMessageMicroSecondTimestamp\x12\x13\n\x0btimestampMS\x18\x01 \x01(\x03\x12\x18\n\x10microSecondsBits\x18\x02 \x01(\x05\"7\n\x10PrivateReplyInfo\x12\x11\n\tcommentID\x18\x01 \x01(\t\x12\x10\n\x08postLink\x18\x02 \x01(\t\"-\n\x10\x46orwardingParams\x12\x19\n\x11\x66orwardedThreadID\x18\x01 \x01(\t\"2\n\x12\x45phemeralityParams\x12\x1c\n\x14\x65phemeralDurationSec\x18\x01 \x01(\x03\"\x06\n\x04Like\"\xa6\x01\n\x10ReceiverFetchXma\x12\x12\n\ncontentRef\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12/\n\x05media\x18\x03 \x01(\x0b\x32 .InstamadilloCoreTypeMedia.Media\x12?\n\rxmaContentRef\x18\x04 \x01(\x0b\x32(.InstamadilloXmaContentRef.XmaContentRef\"\xaa\x02\n\x0bPlaceholder\x12\x41\n\x0fplaceholderType\x18\x01 \x01(\x0e\x32(.InstamadilloAddMessage.Placeholder.Type\"\xd7\x01\n\x04Type\x12\x19\n\x15PLACEHOLDER_TYPE_NONE\x10\x00\x12\'\n#PLACEHOLDER_TYPE_DECRYPTION_FAILURE\x10\x01\x12.\n*PLACEHOLDER_TYPE_NOT_SUPPORTED_NEED_UPDATE\x10\x02\x12\'\n#PLACEHOLDER_TYPE_DEVICE_UNAVAILABLE\x10\x03\x12\x32\n.PLACEHOLDER_TYPE_NOT_SUPPORTED_NOT_RECOVERABLE\x10\x04\x42\x32Z0go.mau.fi/whatsmeow/proto/instamadilloAddMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloAddMessage.InstamadilloAddMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0go.mau.fi/whatsmeow/proto/instamadilloAddMessage'
  _globals['_ADDMESSAGEPAYLOAD']._serialized_start=521
  _globals['_ADDMESSAGEPAYLOAD']._serialized_end=662
  _globals['_ADDMESSAGECONTENT']._serialized_start=665
  _globals['_ADDMESSAGECONTENT']._serialized_end=1229
  _globals['_ADDMESSAGEMETADATA']._serialized_start=1232
  _globals['_ADDMESSAGEMETADATA']._serialized_end=1550
  _globals['_REPLIEDTOMESSAGE']._serialized_start=1553
  _globals['_REPLIEDTOMESSAGE']._serialized_end=1763
  _globals['_OPENMESSAGEMICROSECONDTIMESTAMP']._serialized_start=1765
  _globals['_OPENMESSAGEMICROSECONDTIMESTAMP']._serialized_end=1845
  _globals['_PRIVATEREPLYINFO']._serialized_start=1847
  _globals['_PRIVATEREPLYINFO']._serialized_end=1902
  _globals['_FORWARDINGPARAMS']._serialized_start=1904
  _globals['_FORWARDINGPARAMS']._serialized_end=1949
  _globals['_EPHEMERALITYPARAMS']._serialized_start=1951
  _globals['_EPHEMERALITYPARAMS']._serialized_end=2001
  _globals['_LIKE']._serialized_start=2003
  _globals['_LIKE']._serialized_end=2009
  _globals['_RECEIVERFETCHXMA']._serialized_start=2012
  _globals['_RECEIVERFETCHXMA']._serialized_end=2178
  _globals['_PLACEHOLDER']._serialized_start=2181
  _globals['_PLACEHOLDER']._serialized_end=2479
  _globals['_PLACEHOLDER_TYPE']._serialized_start=2264
  _globals['_PLACEHOLDER_TYPE']._serialized_end=2479
# @@protoc_insertion_point(module_scope)
