"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SupplementMessagePayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGETMESSAGEOTID_FIELD_NUMBER: builtins.int
    UNIQUINGKEYFORSUPPLEMENTALDATA_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TARGETMESSAGEWASERVERTIMESEC_FIELD_NUMBER: builtins.int
    TARGETWATHREADID_FIELD_NUMBER: builtins.int
    targetMessageOtid: builtins.str
    uniquingKeyForSupplementalData: builtins.str
    targetMessageWaServerTimeSec: builtins.str
    targetWaThreadID: builtins.str
    @property
    def content(self) -> global___SupplementMessageContent: ...
    def __init__(
        self,
        *,
        targetMessageOtid: builtins.str | None = ...,
        uniquingKeyForSupplementalData: builtins.str | None = ...,
        content: global___SupplementMessageContent | None = ...,
        targetMessageWaServerTimeSec: builtins.str | None = ...,
        targetWaThreadID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "targetMessageOtid", b"targetMessageOtid", "targetMessageWaServerTimeSec", b"targetMessageWaServerTimeSec", "targetWaThreadID", b"targetWaThreadID", "uniquingKeyForSupplementalData", b"uniquingKeyForSupplementalData"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "targetMessageOtid", b"targetMessageOtid", "targetMessageWaServerTimeSec", b"targetMessageWaServerTimeSec", "targetWaThreadID", b"targetWaThreadID", "uniquingKeyForSupplementalData", b"uniquingKeyForSupplementalData"]) -> None: ...

global___SupplementMessagePayload = SupplementMessagePayload

@typing.final
class SupplementMessageContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REACTION_FIELD_NUMBER: builtins.int
    CONTENTVIEW_FIELD_NUMBER: builtins.int
    EDITTEXT_FIELD_NUMBER: builtins.int
    MEDIAREACTION_FIELD_NUMBER: builtins.int
    ORIGINALTRANSPORTPAYLOAD_FIELD_NUMBER: builtins.int
    MEDIAINTERVENTIONS_FIELD_NUMBER: builtins.int
    @property
    def reaction(self) -> global___Reaction: ...
    @property
    def contentView(self) -> global___ContentView: ...
    @property
    def editText(self) -> global___EditText: ...
    @property
    def mediaReaction(self) -> global___MediaReaction: ...
    @property
    def originalTransportPayload(self) -> global___OriginalTransportPayload: ...
    @property
    def mediaInterventions(self) -> global___MediaInterventions: ...
    def __init__(
        self,
        *,
        reaction: global___Reaction | None = ...,
        contentView: global___ContentView | None = ...,
        editText: global___EditText | None = ...,
        mediaReaction: global___MediaReaction | None = ...,
        originalTransportPayload: global___OriginalTransportPayload | None = ...,
        mediaInterventions: global___MediaInterventions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["contentView", b"contentView", "editText", b"editText", "mediaInterventions", b"mediaInterventions", "mediaReaction", b"mediaReaction", "originalTransportPayload", b"originalTransportPayload", "reaction", b"reaction", "supplementMessageContent", b"supplementMessageContent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["contentView", b"contentView", "editText", b"editText", "mediaInterventions", b"mediaInterventions", "mediaReaction", b"mediaReaction", "originalTransportPayload", b"originalTransportPayload", "reaction", b"reaction", "supplementMessageContent", b"supplementMessageContent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["supplementMessageContent", b"supplementMessageContent"]) -> typing.Literal["reaction", "contentView", "editText", "mediaReaction", "originalTransportPayload", "mediaInterventions"] | None: ...

global___SupplementMessageContent = SupplementMessageContent

@typing.final
class MediaReaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIAID_FIELD_NUMBER: builtins.int
    REACTION_FIELD_NUMBER: builtins.int
    mediaID: builtins.str
    @property
    def reaction(self) -> global___Reaction: ...
    def __init__(
        self,
        *,
        mediaID: builtins.str | None = ...,
        reaction: global___Reaction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mediaID", b"mediaID", "reaction", b"reaction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mediaID", b"mediaID", "reaction", b"reaction"]) -> None: ...

global___MediaReaction = MediaReaction

@typing.final
class Reaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REACTIONTYPE_FIELD_NUMBER: builtins.int
    REACTIONSTATUS_FIELD_NUMBER: builtins.int
    EMOJI_FIELD_NUMBER: builtins.int
    SUPERREACTTYPE_FIELD_NUMBER: builtins.int
    ACTIONLOGOTID_FIELD_NUMBER: builtins.int
    reactionType: builtins.str
    reactionStatus: builtins.str
    emoji: builtins.str
    superReactType: builtins.str
    actionLogOtid: builtins.str
    def __init__(
        self,
        *,
        reactionType: builtins.str | None = ...,
        reactionStatus: builtins.str | None = ...,
        emoji: builtins.str | None = ...,
        superReactType: builtins.str | None = ...,
        actionLogOtid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["actionLogOtid", b"actionLogOtid", "emoji", b"emoji", "reactionStatus", b"reactionStatus", "reactionType", b"reactionType", "superReactType", b"superReactType"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["actionLogOtid", b"actionLogOtid", "emoji", b"emoji", "reactionStatus", b"reactionStatus", "reactionType", b"reactionType", "superReactType", b"superReactType"]) -> None: ...

global___Reaction = Reaction

@typing.final
class ContentView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEEN_FIELD_NUMBER: builtins.int
    SCREENSHOTTED_FIELD_NUMBER: builtins.int
    REPLAYED_FIELD_NUMBER: builtins.int
    MIMETYPE_FIELD_NUMBER: builtins.int
    OBJECTID_FIELD_NUMBER: builtins.int
    seen: builtins.bool
    screenshotted: builtins.bool
    replayed: builtins.bool
    mimetype: builtins.str
    objectID: builtins.str
    def __init__(
        self,
        *,
        seen: builtins.bool | None = ...,
        screenshotted: builtins.bool | None = ...,
        replayed: builtins.bool | None = ...,
        mimetype: builtins.str | None = ...,
        objectID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mimetype", b"mimetype", "objectID", b"objectID", "replayed", b"replayed", "screenshotted", b"screenshotted", "seen", b"seen"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mimetype", b"mimetype", "objectID", b"objectID", "replayed", b"replayed", "screenshotted", b"screenshotted", "seen", b"seen"]) -> None: ...

global___ContentView = ContentView

@typing.final
class EditText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWCONTENT_FIELD_NUMBER: builtins.int
    EDITCOUNT_FIELD_NUMBER: builtins.int
    newContent: builtins.str
    editCount: builtins.int
    def __init__(
        self,
        *,
        newContent: builtins.str | None = ...,
        editCount: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editCount", b"editCount", "newContent", b"newContent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["editCount", b"editCount", "newContent", b"newContent"]) -> None: ...

global___EditText = EditText

@typing.final
class OriginalTransportPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINALTRANSPORTPAYLOAD_FIELD_NUMBER: builtins.int
    originalTransportPayload: builtins.bytes
    def __init__(
        self,
        *,
        originalTransportPayload: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["originalTransportPayload", b"originalTransportPayload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["originalTransportPayload", b"originalTransportPayload"]) -> None: ...

global___OriginalTransportPayload = OriginalTransportPayload

@typing.final
class MediaInterventions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIAID_FIELD_NUMBER: builtins.int
    INTERVENTIONTYPE_FIELD_NUMBER: builtins.int
    mediaID: builtins.str
    interventionType: instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.Media.InterventionType.ValueType
    def __init__(
        self,
        *,
        mediaID: builtins.str | None = ...,
        interventionType: instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.Media.InterventionType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interventionType", b"interventionType", "mediaID", b"mediaID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["interventionType", b"interventionType", "mediaID", b"mediaID"]) -> None: ...

global___MediaInterventions = MediaInterventions
