# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waStatusAttributions/WAWebProtobufsStatusAttributions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;waStatusAttributions/WAWebProtobufsStatusAttributions.proto\x12 WAWebProtobufsStatusAttributions\"\xda\n\n\x11StatusAttribution\x12Z\n\rstatusReshare\x18\x03 \x01(\x0b\x32\x41.WAWebProtobufsStatusAttributions.StatusAttribution.StatusReshareH\x00\x12Z\n\rexternalShare\x18\x04 \x01(\x0b\x32\x41.WAWebProtobufsStatusAttributions.StatusAttribution.ExternalShareH\x00\x12J\n\x05music\x18\x05 \x01(\x0b\x32\x39.WAWebProtobufsStatusAttributions.StatusAttribution.MusicH\x00\x12V\n\x0bgroupStatus\x18\x06 \x01(\x0b\x32?.WAWebProtobufsStatusAttributions.StatusAttribution.GroupStatusH\x00\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.WAWebProtobufsStatusAttributions.StatusAttribution.Type\x12\x11\n\tactionURL\x18\x02 \x01(\t\x1a\xf9\x01\n\rExternalShare\x12\x11\n\tactionURL\x18\x01 \x01(\t\x12X\n\x06source\x18\x02 \x01(\x0e\x32H.WAWebProtobufsStatusAttributions.StatusAttribution.ExternalShare.Source\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12\x19\n\x11\x61\x63tionFallbackURL\x18\x04 \x01(\t\"N\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tINSTAGRAM\x10\x01\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x02\x12\r\n\tMESSENGER\x10\x03\x12\x0b\n\x07SPOTIFY\x10\x04\x1a\x87\x03\n\rStatusReshare\x12X\n\x06source\x18\x01 \x01(\x0e\x32H.WAWebProtobufsStatusAttributions.StatusAttribution.StatusReshare.Source\x12\\\n\x08metadata\x18\x02 \x01(\x0b\x32J.WAWebProtobufsStatusAttributions.StatusAttribution.StatusReshare.Metadata\x1ag\n\x08Metadata\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x12\n\nchannelJID\x18\x02 \x01(\t\x12\x18\n\x10\x63hannelMessageID\x18\x03 \x01(\x05\x12\x1b\n\x13hasMultipleReshares\x18\x04 \x01(\x08\"U\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10INTERNAL_RESHARE\x10\x01\x12\x13\n\x0fMENTION_RESHARE\x10\x02\x12\x13\n\x0f\x43HANNEL_RESHARE\x10\x03\x1a \n\x0bGroupStatus\x12\x11\n\tauthorJID\x18\x01 \x01(\t\x1ay\n\x05Music\x12\x12\n\nauthorName\x18\x01 \x01(\t\x12\x0e\n\x06songID\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x19\n\x11\x61rtistAttribution\x18\x05 \x01(\t\x12\x12\n\nisExplicit\x18\x06 \x01(\x08\"X\n\x04Type\x12\x0b\n\x07RESHARE\x10\x00\x12\x12\n\x0e\x45XTERNAL_SHARE\x10\x01\x12\t\n\x05MUSIC\x10\x02\x12\x12\n\x0eSTATUS_MENTION\x10\x03\x12\x10\n\x0cGROUP_STATUS\x10\x04\x42\x11\n\x0f\x61ttributionDataB0Z.go.mau.fi/whatsmeow/proto/waStatusAttributions')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waStatusAttributions.WAWebProtobufsStatusAttributions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.go.mau.fi/whatsmeow/proto/waStatusAttributions'
  _globals['_STATUSATTRIBUTION']._serialized_start=98
  _globals['_STATUSATTRIBUTION']._serialized_end=1468
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE']._serialized_start=559
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE']._serialized_end=808
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE_SOURCE']._serialized_start=730
  _globals['_STATUSATTRIBUTION_EXTERNALSHARE_SOURCE']._serialized_end=808
  _globals['_STATUSATTRIBUTION_STATUSRESHARE']._serialized_start=811
  _globals['_STATUSATTRIBUTION_STATUSRESHARE']._serialized_end=1202
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_METADATA']._serialized_start=1012
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_METADATA']._serialized_end=1115
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_SOURCE']._serialized_start=1117
  _globals['_STATUSATTRIBUTION_STATUSRESHARE_SOURCE']._serialized_end=1202
  _globals['_STATUSATTRIBUTION_GROUPSTATUS']._serialized_start=1204
  _globals['_STATUSATTRIBUTION_GROUPSTATUS']._serialized_end=1236
  _globals['_STATUSATTRIBUTION_MUSIC']._serialized_start=1238
  _globals['_STATUSATTRIBUTION_MUSIC']._serialized_end=1359
  _globals['_STATUSATTRIBUTION_TYPE']._serialized_start=1361
  _globals['_STATUSATTRIBUTION_TYPE']._serialized_end=1449
# @@protoc_insertion_point(module_scope)
