# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeText/InstamadilloCoreTypeText.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeText/InstamadilloCoreTypeText.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7instamadilloCoreTypeText/InstamadilloCoreTypeText.proto\x12\x18InstamadilloCoreTypeText\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"\xf1\x03\n\x04Text\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x18\n\x10isSuggestedReply\x18\x02 \x01(\x08\x12\x17\n\x0fpostbackPayload\x18\x03 \x01(\t\x12;\n\x0bpowerUpData\x18\x04 \x01(\x0b\x32&.InstamadilloCoreTypeText.PowerUpsData\x12<\n\x08\x63ommands\x18\x05 \x03(\x0b\x32*.InstamadilloCoreTypeText.CommandRangeData\x12[\n\x1c\x61nimatedEmojiCharacterRanges\x18\x06 \x03(\x0b\x32\x35.InstamadilloCoreTypeText.AnimatedEmojiCharacterRange\"\xcf\x01\n\x0b\x46ormatStyle\x12!\n\x1dTEXT_FORMAT_STYLE_UNSPECIFIED\x10\x00\x12\x1a\n\x16TEXT_FORMAT_STYLE_BOLD\x10\x01\x12\x1c\n\x18TEXT_FORMAT_STYLE_ITALIC\x10\x02\x12#\n\x1fTEXT_FORMAT_STYLE_STRIKETHROUGH\x10\x03\x12\x1f\n\x1bTEXT_FORMAT_STYLE_UNDERLINE\x10\x04\x12\x1d\n\x19TEXT_FORMAT_STYLE_INVALID\x10\x05\"g\n\x0cPowerUpsData\x12\r\n\x05style\x18\x01 \x01(\x05\x12H\n\x0fmediaAttachment\x18\x02 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\"h\n\x10\x43ommandRangeData\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0c\n\x04\x46\x42ID\x18\x04 \x01(\t\x12\x18\n\x10userOrThreadFbid\x18\x05 \x01(\t\"j\n\rFormattedText\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x05\x12\x39\n\x05style\x18\x03 \x01(\x0e\x32*.InstamadilloCoreTypeText.Text.FormatStyle\"=\n\x1b\x41nimatedEmojiCharacterRange\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x05\x42\x34Z2go.mau.fi/whatsmeow/proto/instamadilloCoreTypeText')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeText.InstamadilloCoreTypeText_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2go.mau.fi/whatsmeow/proto/instamadilloCoreTypeText'
  _globals['_TEXT']._serialized_start=145
  _globals['_TEXT']._serialized_end=642
  _globals['_TEXT_FORMATSTYLE']._serialized_start=435
  _globals['_TEXT_FORMATSTYLE']._serialized_end=642
  _globals['_POWERUPSDATA']._serialized_start=644
  _globals['_POWERUPSDATA']._serialized_end=747
  _globals['_COMMANDRANGEDATA']._serialized_start=749
  _globals['_COMMANDRANGEDATA']._serialized_end=853
  _globals['_FORMATTEDTEXT']._serialized_start=855
  _globals['_FORMATTEDTEXT']._serialized_end=961
  _globals['_ANIMATEDEMOJICHARACTERRANGE']._serialized_start=963
  _globals['_ANIMATEDEMOJICHARACTERRANGE']._serialized_end=1024
# @@protoc_insertion_point(module_scope)
