"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _XmaActionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _XmaActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_XmaActionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    XMA_ACTION_TYPE_UNSPECIFIED: _XmaActionType.ValueType  # 0
    XMA_ACTION_TYPE_SHARE: _XmaActionType.ValueType  # 1
    XMA_ACTION_TYPE_REPLY: _XmaActionType.ValueType  # 2
    XMA_ACTION_TYPE_REACT: _XmaActionType.ValueType  # 3
    XMA_ACTION_TYPE_MENTION: _XmaActionType.ValueType  # 4

class XmaActionType(_XmaActionType, metaclass=_XmaActionTypeEnumTypeWrapper): ...

XMA_ACTION_TYPE_UNSPECIFIED: XmaActionType.ValueType  # 0
XMA_ACTION_TYPE_SHARE: XmaActionType.ValueType  # 1
XMA_ACTION_TYPE_REPLY: XmaActionType.ValueType  # 2
XMA_ACTION_TYPE_REACT: XmaActionType.ValueType  # 3
XMA_ACTION_TYPE_MENTION: XmaActionType.ValueType  # 4
global___XmaActionType = XmaActionType

class _ReceiverFetchContentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReceiverFetchContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReceiverFetchContentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RECEIVER_FETCH_CONTENT_TYPE_UNSPECIFIED: _ReceiverFetchContentType.ValueType  # 0
    RECEIVER_FETCH_CONTENT_TYPE_NOTE: _ReceiverFetchContentType.ValueType  # 1
    RECEIVER_FETCH_CONTENT_TYPE_STORY: _ReceiverFetchContentType.ValueType  # 2
    RECEIVER_FETCH_CONTENT_TYPE_PROFILE: _ReceiverFetchContentType.ValueType  # 3
    RECEIVER_FETCH_CONTENT_TYPE_CLIP: _ReceiverFetchContentType.ValueType  # 4
    RECEIVER_FETCH_CONTENT_TYPE_FEED: _ReceiverFetchContentType.ValueType  # 5
    RECEIVER_FETCH_CONTENT_TYPE_LIVE: _ReceiverFetchContentType.ValueType  # 6
    RECEIVER_FETCH_CONTENT_TYPE_COMMENT: _ReceiverFetchContentType.ValueType  # 7
    RECEIVER_FETCH_CONTENT_TYPE_LOCATION_SHARE: _ReceiverFetchContentType.ValueType  # 8
    RECEIVER_FETCH_CONTENT_TYPE_REELS_AUDIO: _ReceiverFetchContentType.ValueType  # 9
    RECEIVER_FETCH_CONTENT_TYPE_MEDIA_NOTE: _ReceiverFetchContentType.ValueType  # 10
    RECEIVER_FETCH_CONTENT_TYPE_STORY_HIGHLIGHT: _ReceiverFetchContentType.ValueType  # 11
    RECEIVER_FETCH_CONTENT_TYPE_SOCIAL_CONTEXT: _ReceiverFetchContentType.ValueType  # 12

class ReceiverFetchContentType(_ReceiverFetchContentType, metaclass=_ReceiverFetchContentTypeEnumTypeWrapper): ...

RECEIVER_FETCH_CONTENT_TYPE_UNSPECIFIED: ReceiverFetchContentType.ValueType  # 0
RECEIVER_FETCH_CONTENT_TYPE_NOTE: ReceiverFetchContentType.ValueType  # 1
RECEIVER_FETCH_CONTENT_TYPE_STORY: ReceiverFetchContentType.ValueType  # 2
RECEIVER_FETCH_CONTENT_TYPE_PROFILE: ReceiverFetchContentType.ValueType  # 3
RECEIVER_FETCH_CONTENT_TYPE_CLIP: ReceiverFetchContentType.ValueType  # 4
RECEIVER_FETCH_CONTENT_TYPE_FEED: ReceiverFetchContentType.ValueType  # 5
RECEIVER_FETCH_CONTENT_TYPE_LIVE: ReceiverFetchContentType.ValueType  # 6
RECEIVER_FETCH_CONTENT_TYPE_COMMENT: ReceiverFetchContentType.ValueType  # 7
RECEIVER_FETCH_CONTENT_TYPE_LOCATION_SHARE: ReceiverFetchContentType.ValueType  # 8
RECEIVER_FETCH_CONTENT_TYPE_REELS_AUDIO: ReceiverFetchContentType.ValueType  # 9
RECEIVER_FETCH_CONTENT_TYPE_MEDIA_NOTE: ReceiverFetchContentType.ValueType  # 10
RECEIVER_FETCH_CONTENT_TYPE_STORY_HIGHLIGHT: ReceiverFetchContentType.ValueType  # 11
RECEIVER_FETCH_CONTENT_TYPE_SOCIAL_CONTEXT: ReceiverFetchContentType.ValueType  # 12
global___ReceiverFetchContentType = ReceiverFetchContentType

class _MediaNoteFetchParamsMessageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaNoteFetchParamsMessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaNoteFetchParamsMessageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_UNSPECIFIED: _MediaNoteFetchParamsMessageType.ValueType  # 0
    MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_MENTION: _MediaNoteFetchParamsMessageType.ValueType  # 1
    MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_REPLY: _MediaNoteFetchParamsMessageType.ValueType  # 2

class MediaNoteFetchParamsMessageType(_MediaNoteFetchParamsMessageType, metaclass=_MediaNoteFetchParamsMessageTypeEnumTypeWrapper): ...

MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_UNSPECIFIED: MediaNoteFetchParamsMessageType.ValueType  # 0
MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_MENTION: MediaNoteFetchParamsMessageType.ValueType  # 1
MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_REPLY: MediaNoteFetchParamsMessageType.ValueType  # 2
global___MediaNoteFetchParamsMessageType = MediaNoteFetchParamsMessageType

@typing.final
class XmaContentRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONTYPE_FIELD_NUMBER: builtins.int
    CONTENTTYPE_FIELD_NUMBER: builtins.int
    TARGETURL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    OWNERFBID_FIELD_NUMBER: builtins.int
    FETCHPARAMS_FIELD_NUMBER: builtins.int
    actionType: global___XmaActionType.ValueType
    contentType: global___ReceiverFetchContentType.ValueType
    targetURL: builtins.str
    userName: builtins.str
    ownerFbid: builtins.str
    @property
    def fetchParams(self) -> global___ReceiverFetchXmaFetchParams: ...
    def __init__(
        self,
        *,
        actionType: global___XmaActionType.ValueType | None = ...,
        contentType: global___ReceiverFetchContentType.ValueType | None = ...,
        targetURL: builtins.str | None = ...,
        userName: builtins.str | None = ...,
        ownerFbid: builtins.str | None = ...,
        fetchParams: global___ReceiverFetchXmaFetchParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["actionType", b"actionType", "contentType", b"contentType", "fetchParams", b"fetchParams", "ownerFbid", b"ownerFbid", "targetURL", b"targetURL", "userName", b"userName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["actionType", b"actionType", "contentType", b"contentType", "fetchParams", b"fetchParams", "ownerFbid", b"ownerFbid", "targetURL", b"targetURL", "userName", b"userName"]) -> None: ...

global___XmaContentRef = XmaContentRef

@typing.final
class ReceiverFetchXmaFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTEFETCHPARAMS_FIELD_NUMBER: builtins.int
    STORYFETCHPARAMS_FIELD_NUMBER: builtins.int
    PROFILEFETCHPARAMS_FIELD_NUMBER: builtins.int
    CLIPFETCHPARAMS_FIELD_NUMBER: builtins.int
    FEEDFETCHPARAMS_FIELD_NUMBER: builtins.int
    LIVEFETCHPARAMS_FIELD_NUMBER: builtins.int
    COMMENTFETCHPARAMS_FIELD_NUMBER: builtins.int
    LOCATIONSHAREFETCHPARAMS_FIELD_NUMBER: builtins.int
    REELSAUDIOFETCHPARAMS_FIELD_NUMBER: builtins.int
    MEDIANOTEFETCHPARAMS_FIELD_NUMBER: builtins.int
    SOCIALCONTEXTFETCHPARAMS_FIELD_NUMBER: builtins.int
    @property
    def noteFetchParams(self) -> global___ReceiverFetchXmaNoteFetchParams: ...
    @property
    def storyFetchParams(self) -> global___ReceiverFetchXmaStoryFetchParams: ...
    @property
    def profileFetchParams(self) -> global___ReceiverFetchXmaProfileFetchParams: ...
    @property
    def clipFetchParams(self) -> global___ReceiverFetchXmaClipFetchParams: ...
    @property
    def feedFetchParams(self) -> global___ReceiverFetchXmaFeedFetchParams: ...
    @property
    def liveFetchParams(self) -> global___ReceiverFetchXmaLiveFetchParams: ...
    @property
    def commentFetchParams(self) -> global___ReceiverFetchXmaCommentFetchParams: ...
    @property
    def locationShareFetchParams(self) -> global___ReceiverFetchXmaLocationShareFetchParams: ...
    @property
    def reelsAudioFetchParams(self) -> global___ReceiverFetchXmaReelsAudioFetchParams: ...
    @property
    def mediaNoteFetchParams(self) -> global___ReceiverFetchXmaMediaNoteFetchParams: ...
    @property
    def socialContextFetchParams(self) -> global___ReceiverFetchXmaSocialContextFetchParams: ...
    def __init__(
        self,
        *,
        noteFetchParams: global___ReceiverFetchXmaNoteFetchParams | None = ...,
        storyFetchParams: global___ReceiverFetchXmaStoryFetchParams | None = ...,
        profileFetchParams: global___ReceiverFetchXmaProfileFetchParams | None = ...,
        clipFetchParams: global___ReceiverFetchXmaClipFetchParams | None = ...,
        feedFetchParams: global___ReceiverFetchXmaFeedFetchParams | None = ...,
        liveFetchParams: global___ReceiverFetchXmaLiveFetchParams | None = ...,
        commentFetchParams: global___ReceiverFetchXmaCommentFetchParams | None = ...,
        locationShareFetchParams: global___ReceiverFetchXmaLocationShareFetchParams | None = ...,
        reelsAudioFetchParams: global___ReceiverFetchXmaReelsAudioFetchParams | None = ...,
        mediaNoteFetchParams: global___ReceiverFetchXmaMediaNoteFetchParams | None = ...,
        socialContextFetchParams: global___ReceiverFetchXmaSocialContextFetchParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clipFetchParams", b"clipFetchParams", "commentFetchParams", b"commentFetchParams", "feedFetchParams", b"feedFetchParams", "liveFetchParams", b"liveFetchParams", "locationShareFetchParams", b"locationShareFetchParams", "mediaNoteFetchParams", b"mediaNoteFetchParams", "noteFetchParams", b"noteFetchParams", "profileFetchParams", b"profileFetchParams", "receiverFetchXmaFetchParams", b"receiverFetchXmaFetchParams", "reelsAudioFetchParams", b"reelsAudioFetchParams", "socialContextFetchParams", b"socialContextFetchParams", "storyFetchParams", b"storyFetchParams"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clipFetchParams", b"clipFetchParams", "commentFetchParams", b"commentFetchParams", "feedFetchParams", b"feedFetchParams", "liveFetchParams", b"liveFetchParams", "locationShareFetchParams", b"locationShareFetchParams", "mediaNoteFetchParams", b"mediaNoteFetchParams", "noteFetchParams", b"noteFetchParams", "profileFetchParams", b"profileFetchParams", "receiverFetchXmaFetchParams", b"receiverFetchXmaFetchParams", "reelsAudioFetchParams", b"reelsAudioFetchParams", "socialContextFetchParams", b"socialContextFetchParams", "storyFetchParams", b"storyFetchParams"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["receiverFetchXmaFetchParams", b"receiverFetchXmaFetchParams"]) -> typing.Literal["noteFetchParams", "storyFetchParams", "profileFetchParams", "clipFetchParams", "feedFetchParams", "liveFetchParams", "commentFetchParams", "locationShareFetchParams", "reelsAudioFetchParams", "mediaNoteFetchParams", "socialContextFetchParams"] | None: ...

global___ReceiverFetchXmaFetchParams = ReceiverFetchXmaFetchParams

@typing.final
class ReceiverFetchXmaNoteFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTEIGID_FIELD_NUMBER: builtins.int
    noteIgid: builtins.str
    def __init__(
        self,
        *,
        noteIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["noteIgid", b"noteIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["noteIgid", b"noteIgid"]) -> None: ...

global___ReceiverFetchXmaNoteFetchParams = ReceiverFetchXmaNoteFetchParams

@typing.final
class ReceiverFetchXmaStoryFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORYIGID_FIELD_NUMBER: builtins.int
    REELID_FIELD_NUMBER: builtins.int
    storyIgid: builtins.str
    reelID: builtins.str
    def __init__(
        self,
        *,
        storyIgid: builtins.str | None = ...,
        reelID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["reelID", b"reelID", "storyIgid", b"storyIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["reelID", b"reelID", "storyIgid", b"storyIgid"]) -> None: ...

global___ReceiverFetchXmaStoryFetchParams = ReceiverFetchXmaStoryFetchParams

@typing.final
class ReceiverFetchXmaProfileFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROFILEIGID_FIELD_NUMBER: builtins.int
    profileIgid: builtins.str
    def __init__(
        self,
        *,
        profileIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["profileIgid", b"profileIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["profileIgid", b"profileIgid"]) -> None: ...

global___ReceiverFetchXmaProfileFetchParams = ReceiverFetchXmaProfileFetchParams

@typing.final
class ReceiverFetchXmaClipFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIAIGID_FIELD_NUMBER: builtins.int
    mediaIgid: builtins.str
    def __init__(
        self,
        *,
        mediaIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mediaIgid", b"mediaIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mediaIgid", b"mediaIgid"]) -> None: ...

global___ReceiverFetchXmaClipFetchParams = ReceiverFetchXmaClipFetchParams

@typing.final
class ReceiverFetchXmaFeedFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIAIGID_FIELD_NUMBER: builtins.int
    CAROUSELSHARECHILDMEDIAIGID_FIELD_NUMBER: builtins.int
    mediaIgid: builtins.str
    carouselShareChildMediaIgid: builtins.str
    def __init__(
        self,
        *,
        mediaIgid: builtins.str | None = ...,
        carouselShareChildMediaIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["carouselShareChildMediaIgid", b"carouselShareChildMediaIgid", "mediaIgid", b"mediaIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["carouselShareChildMediaIgid", b"carouselShareChildMediaIgid", "mediaIgid", b"mediaIgid"]) -> None: ...

global___ReceiverFetchXmaFeedFetchParams = ReceiverFetchXmaFeedFetchParams

@typing.final
class ReceiverFetchXmaLiveFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVEIGID_FIELD_NUMBER: builtins.int
    liveIgid: builtins.str
    def __init__(
        self,
        *,
        liveIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["liveIgid", b"liveIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["liveIgid", b"liveIgid"]) -> None: ...

global___ReceiverFetchXmaLiveFetchParams = ReceiverFetchXmaLiveFetchParams

@typing.final
class ReceiverFetchXmaCommentFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMENTFBID_FIELD_NUMBER: builtins.int
    commentFbid: builtins.str
    def __init__(
        self,
        *,
        commentFbid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["commentFbid", b"commentFbid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["commentFbid", b"commentFbid"]) -> None: ...

global___ReceiverFetchXmaCommentFetchParams = ReceiverFetchXmaCommentFetchParams

@typing.final
class ReceiverFetchXmaLocationShareFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATIONIGID_FIELD_NUMBER: builtins.int
    locationIgid: builtins.str
    def __init__(
        self,
        *,
        locationIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["locationIgid", b"locationIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["locationIgid", b"locationIgid"]) -> None: ...

global___ReceiverFetchXmaLocationShareFetchParams = ReceiverFetchXmaLocationShareFetchParams

@typing.final
class ReceiverFetchXmaReelsAudioFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIOIGID_FIELD_NUMBER: builtins.int
    audioIgid: builtins.str
    def __init__(
        self,
        *,
        audioIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audioIgid", b"audioIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audioIgid", b"audioIgid"]) -> None: ...

global___ReceiverFetchXmaReelsAudioFetchParams = ReceiverFetchXmaReelsAudioFetchParams

@typing.final
class ReceiverFetchXmaMediaNoteFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIANOTEIGID_FIELD_NUMBER: builtins.int
    MESSAGETYPE_FIELD_NUMBER: builtins.int
    mediaNoteIgid: builtins.str
    messageType: global___MediaNoteFetchParamsMessageType.ValueType
    def __init__(
        self,
        *,
        mediaNoteIgid: builtins.str | None = ...,
        messageType: global___MediaNoteFetchParamsMessageType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mediaNoteIgid", b"mediaNoteIgid", "messageType", b"messageType"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mediaNoteIgid", b"mediaNoteIgid", "messageType", b"messageType"]) -> None: ...

global___ReceiverFetchXmaMediaNoteFetchParams = ReceiverFetchXmaMediaNoteFetchParams

@typing.final
class ReceiverFetchXmaSocialContextFetchParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIAIGID_FIELD_NUMBER: builtins.int
    mediaIgid: builtins.str
    def __init__(
        self,
        *,
        mediaIgid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mediaIgid", b"mediaIgid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mediaIgid", b"mediaIgid"]) -> None: ...

global___ReceiverFetchXmaSocialContextFetchParams = ReceiverFetchXmaSocialContextFetchParams
