"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Link(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LINKCONTEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    @property
    def linkContext(self) -> global___LinkContext: ...
    def __init__(
        self,
        *,
        text: builtins.str | None = ...,
        linkContext: global___LinkContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["linkContext", b"linkContext", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["linkContext", b"linkContext", "text", b"text"]) -> None: ...

global___Link = Link

@typing.final
class LinkContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINKIMAGEURL_FIELD_NUMBER: builtins.int
    LINKPREVIEWTITLE_FIELD_NUMBER: builtins.int
    LINKURL_FIELD_NUMBER: builtins.int
    LINKSUMMARY_FIELD_NUMBER: builtins.int
    LINKMUSICPREVIEWURL_FIELD_NUMBER: builtins.int
    LINKMUSICPREVIEWCOUNTRIESALLOWED_FIELD_NUMBER: builtins.int
    LINKPREVIEWTHUMBNAIL_FIELD_NUMBER: builtins.int
    LINKPREVIEWBODY_FIELD_NUMBER: builtins.int
    linkPreviewTitle: builtins.str
    linkURL: builtins.str
    linkSummary: builtins.str
    linkMusicPreviewURL: builtins.str
    linkPreviewBody: builtins.str
    @property
    def linkImageURL(self) -> global___ImageUrl: ...
    @property
    def linkMusicPreviewCountriesAllowed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def linkPreviewThumbnail(self) -> instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.Thumbnail: ...
    def __init__(
        self,
        *,
        linkImageURL: global___ImageUrl | None = ...,
        linkPreviewTitle: builtins.str | None = ...,
        linkURL: builtins.str | None = ...,
        linkSummary: builtins.str | None = ...,
        linkMusicPreviewURL: builtins.str | None = ...,
        linkMusicPreviewCountriesAllowed: collections.abc.Iterable[builtins.str] | None = ...,
        linkPreviewThumbnail: instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.Thumbnail | None = ...,
        linkPreviewBody: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["linkImageURL", b"linkImageURL", "linkMusicPreviewURL", b"linkMusicPreviewURL", "linkPreviewBody", b"linkPreviewBody", "linkPreviewThumbnail", b"linkPreviewThumbnail", "linkPreviewTitle", b"linkPreviewTitle", "linkSummary", b"linkSummary", "linkURL", b"linkURL"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["linkImageURL", b"linkImageURL", "linkMusicPreviewCountriesAllowed", b"linkMusicPreviewCountriesAllowed", "linkMusicPreviewURL", b"linkMusicPreviewURL", "linkPreviewBody", b"linkPreviewBody", "linkPreviewThumbnail", b"linkPreviewThumbnail", "linkPreviewTitle", b"linkPreviewTitle", "linkSummary", b"linkSummary", "linkURL", b"linkURL"]) -> None: ...

global___LinkContext = LinkContext

@typing.final
class ImageUrl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    URL: builtins.str
    width: builtins.int
    height: builtins.int
    def __init__(
        self,
        *,
        URL: builtins.str | None = ...,
        width: builtins.int | None = ...,
        height: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["URL", b"URL", "height", b"height", "width", b"width"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["URL", b"URL", "height", b"height", "width", b"width"]) -> None: ...

global___ImageUrl = ImageUrl
