"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Collection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    MEDIA_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def media(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.Media]: ...
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        media: collections.abc.Iterable[instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.Media] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name", b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["media", b"media", "name", b"name"]) -> None: ...

global___Collection = Collection
