"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Text(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _FormatStyle:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FormatStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Text._FormatStyle.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TEXT_FORMAT_STYLE_UNSPECIFIED: Text._FormatStyle.ValueType  # 0
        TEXT_FORMAT_STYLE_BOLD: Text._FormatStyle.ValueType  # 1
        TEXT_FORMAT_STYLE_ITALIC: Text._FormatStyle.ValueType  # 2
        TEXT_FORMAT_STYLE_STRIKETHROUGH: Text._FormatStyle.ValueType  # 3
        TEXT_FORMAT_STYLE_UNDERLINE: Text._FormatStyle.ValueType  # 4
        TEXT_FORMAT_STYLE_INVALID: Text._FormatStyle.ValueType  # 5

    class FormatStyle(_FormatStyle, metaclass=_FormatStyleEnumTypeWrapper): ...
    TEXT_FORMAT_STYLE_UNSPECIFIED: Text.FormatStyle.ValueType  # 0
    TEXT_FORMAT_STYLE_BOLD: Text.FormatStyle.ValueType  # 1
    TEXT_FORMAT_STYLE_ITALIC: Text.FormatStyle.ValueType  # 2
    TEXT_FORMAT_STYLE_STRIKETHROUGH: Text.FormatStyle.ValueType  # 3
    TEXT_FORMAT_STYLE_UNDERLINE: Text.FormatStyle.ValueType  # 4
    TEXT_FORMAT_STYLE_INVALID: Text.FormatStyle.ValueType  # 5

    TEXT_FIELD_NUMBER: builtins.int
    ISSUGGESTEDREPLY_FIELD_NUMBER: builtins.int
    POSTBACKPAYLOAD_FIELD_NUMBER: builtins.int
    POWERUPDATA_FIELD_NUMBER: builtins.int
    COMMANDS_FIELD_NUMBER: builtins.int
    ANIMATEDEMOJICHARACTERRANGES_FIELD_NUMBER: builtins.int
    text: builtins.str
    isSuggestedReply: builtins.bool
    postbackPayload: builtins.str
    @property
    def powerUpData(self) -> global___PowerUpsData: ...
    @property
    def commands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandRangeData]: ...
    @property
    def animatedEmojiCharacterRanges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnimatedEmojiCharacterRange]: ...
    def __init__(
        self,
        *,
        text: builtins.str | None = ...,
        isSuggestedReply: builtins.bool | None = ...,
        postbackPayload: builtins.str | None = ...,
        powerUpData: global___PowerUpsData | None = ...,
        commands: collections.abc.Iterable[global___CommandRangeData] | None = ...,
        animatedEmojiCharacterRanges: collections.abc.Iterable[global___AnimatedEmojiCharacterRange] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isSuggestedReply", b"isSuggestedReply", "postbackPayload", b"postbackPayload", "powerUpData", b"powerUpData", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["animatedEmojiCharacterRanges", b"animatedEmojiCharacterRanges", "commands", b"commands", "isSuggestedReply", b"isSuggestedReply", "postbackPayload", b"postbackPayload", "powerUpData", b"powerUpData", "text", b"text"]) -> None: ...

global___Text = Text

@typing.final
class PowerUpsData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_FIELD_NUMBER: builtins.int
    MEDIAATTACHMENT_FIELD_NUMBER: builtins.int
    style: builtins.int
    @property
    def mediaAttachment(self) -> instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.CommonMediaTransport: ...
    def __init__(
        self,
        *,
        style: builtins.int | None = ...,
        mediaAttachment: instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2.CommonMediaTransport | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mediaAttachment", b"mediaAttachment", "style", b"style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mediaAttachment", b"mediaAttachment", "style", b"style"]) -> None: ...

global___PowerUpsData = PowerUpsData

@typing.final
class CommandRangeData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    FBID_FIELD_NUMBER: builtins.int
    USERORTHREADFBID_FIELD_NUMBER: builtins.int
    offset: builtins.int
    length: builtins.int
    type: builtins.int
    FBID: builtins.str
    userOrThreadFbid: builtins.str
    def __init__(
        self,
        *,
        offset: builtins.int | None = ...,
        length: builtins.int | None = ...,
        type: builtins.int | None = ...,
        FBID: builtins.str | None = ...,
        userOrThreadFbid: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["FBID", b"FBID", "length", b"length", "offset", b"offset", "type", b"type", "userOrThreadFbid", b"userOrThreadFbid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["FBID", b"FBID", "length", b"length", "offset", b"offset", "type", b"type", "userOrThreadFbid", b"userOrThreadFbid"]) -> None: ...

global___CommandRangeData = CommandRangeData

@typing.final
class FormattedText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    offset: builtins.int
    length: builtins.int
    style: global___Text.FormatStyle.ValueType
    def __init__(
        self,
        *,
        offset: builtins.int | None = ...,
        length: builtins.int | None = ...,
        style: global___Text.FormatStyle.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["length", b"length", "offset", b"offset", "style", b"style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["length", b"length", "offset", b"offset", "style", b"style"]) -> None: ...

global___FormattedText = FormattedText

@typing.final
class AnimatedEmojiCharacterRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    offset: builtins.int
    length: builtins.int
    def __init__(
        self,
        *,
        offset: builtins.int | None = ...,
        length: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["length", b"length", "offset", b"offset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["length", b"length", "offset", b"offset"]) -> None: ...

global___AnimatedEmojiCharacterRange = AnimatedEmojiCharacterRange
