# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeAdminMessage/InstamadilloCoreTypeAdminMessage.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeAdminMessage/InstamadilloCoreTypeAdminMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGinstamadilloCoreTypeAdminMessage/InstamadilloCoreTypeAdminMessage.proto\x12 InstamadilloCoreTypeAdminMessage\"y\n\x0c\x41\x64minMessage\x12R\n\x12\x64\x65viceAdminMessage\x18\x01 \x01(\x0b\x32\x34.InstamadilloCoreTypeAdminMessage.DeviceAdminMessageH\x00\x42\x15\n\x13\x61\x64minMessageSubtype\"\x85\x03\n\x12\x44\x65viceAdminMessage\x12Y\n\x16\x64\x65viceAdminMessageType\x18\x01 \x01(\x0e\x32\x39.InstamadilloCoreTypeAdminMessage.DeviceAdminMessage.Type\x12\x12\n\ndeviceName\x18\x02 \x01(\t\"\xff\x01\n\x04Type\x12\"\n\x1e\x44\x45VICE_ADMIN_MESSAGE_TYPE_NONE\x10\x00\x12J\nFDEVICE_ADMIN_MESSAGE_TYPE_LOCAL_USER_CHANGED_IDENTITY_KEY_NAMED_DEVICE\x10\x01\x12\x43\n?DEVICE_ADMIN_MESSAGE_TYPE_SECURITY_ALERT_PARTICIPANT_KEY_CHANGE\x10\x02\x12\x42\n>DEVICE_ADMIN_MESSAGE_TYPE_SECURITY_ALERT_PARTICIPANT_NEW_LOGIN\x10\x03\x42<Z:go.mau.fi/whatsmeow/proto/instamadilloCoreTypeAdminMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeAdminMessage.InstamadilloCoreTypeAdminMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:go.mau.fi/whatsmeow/proto/instamadilloCoreTypeAdminMessage'
  _globals['_ADMINMESSAGE']._serialized_start=109
  _globals['_ADMINMESSAGE']._serialized_end=230
  _globals['_DEVICEADMINMESSAGE']._serialized_start=233
  _globals['_DEVICEADMINMESSAGE']._serialized_end=622
  _globals['_DEVICEADMINMESSAGE_TYPE']._serialized_start=367
  _globals['_DEVICEADMINMESSAGE_TYPE']._serialized_end=622
# @@protoc_insertion_point(module_scope)
