# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\x12\x19InstamadilloCoreTypeMedia\"\x8d\x03\n\x05Media\x12=\n\x0bstaticPhoto\x18\x01 \x01(\x0b\x32&.InstamadilloCoreTypeMedia.StaticPhotoH\x00\x12\x31\n\x05voice\x18\x02 \x01(\x0b\x32 .InstamadilloCoreTypeMedia.VoiceH\x00\x12\x31\n\x05video\x18\x03 \x01(\x0b\x32 .InstamadilloCoreTypeMedia.VideoH\x00\x12\x31\n\x05raven\x18\x04 \x01(\x0b\x32 .InstamadilloCoreTypeMedia.RavenH\x00\x12-\n\x03gif\x18\x05 \x01(\x0b\x32\x1e.InstamadilloCoreTypeMedia.GifH\x00\x12\x41\n\ravatarSticker\x18\x06 \x01(\x0b\x32(.InstamadilloCoreTypeMedia.AvatarStickerH\x00\"1\n\x10InterventionType\x12\t\n\x05UNSET\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x08\n\x04NUDE\x10\x02\x42\x07\n\x05media\"\x9a\x02\n\x0bStaticPhoto\x12G\n\x0emediaTransport\x18\x01 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x17\n\x0bscanLengths\x18\x04 \x03(\x05\x42\x02\x10\x01\x12\x37\n\tthumbnail\x18\x05 \x01(\x0b\x32$.InstamadilloCoreTypeMedia.Thumbnail\x12Q\n\x16pjpegScanConfiguration\x18\x06 \x01(\x0e\x32\x31.InstamadilloCoreTypeMedia.PjpegScanConfiguration\"\x9e\x01\n\x05Voice\x12G\n\x0emediaTransport\x18\x01 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\x15\n\twaveforms\x18\x03 \x03(\x02\x42\x02\x10\x01\x12#\n\x1bwaveformSamplingFrequencyHz\x18\x04 \x01(\x05\"\xf3\x01\n\x05Video\x12G\n\x0emediaTransport\x18\x01 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x37\n\tthumbnail\x18\x04 \x01(\x0b\x32$.InstamadilloCoreTypeMedia.Thumbnail\x12I\n\x12videoExtraMetadata\x18\x05 \x01(\x0b\x32-.InstamadilloCoreTypeMedia.VideoExtraMetadata\"\xc6\x01\n\x03Gif\x12G\n\x0emediaTransport\x18\x01 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x11\n\tisSticker\x18\x04 \x01(\x08\x12\x11\n\tstickerID\x18\x05 \x01(\t\x12\x0e\n\x06gifURL\x18\x06 \x01(\t\x12\x0f\n\x07gifSize\x18\x07 \x01(\x05\x12\x10\n\x08isRandom\x18\x08 \x01(\x08\"\xa9\x01\n\rAvatarSticker\x12G\n\x0emediaTransport\x18\x01 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\x12\x12\n\nisAnimated\x18\x02 \x01(\x08\x12\x11\n\tstickerID\x18\x03 \x01(\t\x12\x17\n\x0fstickerTemplate\x18\x04 \x01(\t\x12\x0f\n\x07nuxType\x18\x05 \x01(\x05\"\x89\x02\n\x05Raven\x12;\n\x08viewMode\x18\x01 \x01(\x0e\x32).InstamadilloCoreTypeMedia.Raven.ViewMode\x12\x38\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\'.InstamadilloCoreTypeMedia.RavenContent\"\x88\x01\n\x08ViewMode\x12 \n\x1cRAVEN_VIEW_MODEL_UNSPECIFIED\x10\x00\x12\x19\n\x15RAVEN_VIEW_MODEL_ONCE\x10\x01\x12\x1f\n\x1bRAVEN_VIEW_MODEL_REPLAYABLE\x10\x02\x12\x1e\n\x1aRAVEN_VIEW_MODEL_PERMANENT\x10\x03\"\x90\x01\n\x0cRavenContent\x12=\n\x0bstaticPhoto\x18\x01 \x01(\x0b\x32&.InstamadilloCoreTypeMedia.StaticPhotoH\x00\x12\x31\n\x05video\x18\x02 \x01(\x0b\x32 .InstamadilloCoreTypeMedia.VideoH\x00\x42\x0e\n\x0cravenContent\"s\n\tThumbnail\x12G\n\x0emediaTransport\x18\x01 \x01(\x0b\x32/.InstamadilloCoreTypeMedia.CommonMediaTransport\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\"\xdc\x01\n\x14\x43ommonMediaTransport\x12\x0f\n\x07mediaID\x18\x01 \x01(\t\x12\x12\n\nfileSHA256\x18\x02 \x01(\t\x12\x10\n\x08mediaKey\x18\x03 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x04 \x01(\t\x12\x12\n\ndirectPath\x18\x05 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x06 \x01(\t\x12\x0f\n\x07sidecar\x18\x07 \x01(\t\x12\x12\n\nfileLength\x18\x08 \x01(\x05\x12\x10\n\x08mimetype\x18\t \x01(\t\x12\x10\n\x08objectID\x18\n \x01(\t\"2\n\x12VideoExtraMetadata\x12\x1c\n\x14uploadMosClientScore\x18\x01 \x01(\x02*\xa7\x01\n\x16PjpegScanConfiguration\x12(\n$PJPEG_SCAN_CONFIGURATION_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPJPEG_SCAN_CONFIGURATION_WA\x10\x01\x12 \n\x1cPJPEG_SCAN_CONFIGURATION_E15\x10\x02\x12 \n\x1cPJPEG_SCAN_CONFIGURATION_E35\x10\x03\x42\x35Z3go.mau.fi/whatsmeow/proto/instamadilloCoreTypeMedia')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeMedia.InstamadilloCoreTypeMedia_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3go.mau.fi/whatsmeow/proto/instamadilloCoreTypeMedia'
  _globals['_STATICPHOTO'].fields_by_name['scanLengths']._loaded_options = None
  _globals['_STATICPHOTO'].fields_by_name['scanLengths']._serialized_options = b'\020\001'
  _globals['_VOICE'].fields_by_name['waveforms']._loaded_options = None
  _globals['_VOICE'].fields_by_name['waveforms']._serialized_options = b'\020\001'
  _globals['_PJPEGSCANCONFIGURATION']._serialized_start=2361
  _globals['_PJPEGSCANCONFIGURATION']._serialized_end=2528
  _globals['_MEDIA']._serialized_start=89
  _globals['_MEDIA']._serialized_end=486
  _globals['_MEDIA_INTERVENTIONTYPE']._serialized_start=428
  _globals['_MEDIA_INTERVENTIONTYPE']._serialized_end=477
  _globals['_STATICPHOTO']._serialized_start=489
  _globals['_STATICPHOTO']._serialized_end=771
  _globals['_VOICE']._serialized_start=774
  _globals['_VOICE']._serialized_end=932
  _globals['_VIDEO']._serialized_start=935
  _globals['_VIDEO']._serialized_end=1178
  _globals['_GIF']._serialized_start=1181
  _globals['_GIF']._serialized_end=1379
  _globals['_AVATARSTICKER']._serialized_start=1382
  _globals['_AVATARSTICKER']._serialized_end=1551
  _globals['_RAVEN']._serialized_start=1554
  _globals['_RAVEN']._serialized_end=1819
  _globals['_RAVEN_VIEWMODE']._serialized_start=1683
  _globals['_RAVEN_VIEWMODE']._serialized_end=1819
  _globals['_RAVENCONTENT']._serialized_start=1822
  _globals['_RAVENCONTENT']._serialized_end=1966
  _globals['_THUMBNAIL']._serialized_start=1968
  _globals['_THUMBNAIL']._serialized_end=2083
  _globals['_COMMONMEDIATRANSPORT']._serialized_start=2086
  _globals['_COMMONMEDIATRANSPORT']._serialized_end=2306
  _globals['_VIDEOEXTRAMETADATA']._serialized_start=2308
  _globals['_VIDEOEXTRAMETADATA']._serialized_end=2358
# @@protoc_insertion_point(module_scope)
