# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7instamadilloCoreTypeLink/InstamadilloCoreTypeLink.proto\x12\x18InstamadilloCoreTypeLink\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"P\n\x04Link\x12\x0c\n\x04text\x18\x01 \x01(\t\x12:\n\x0blinkContext\x18\x02 \x01(\x0b\x32%.InstamadilloCoreTypeLink.LinkContext\"\xab\x02\n\x0bLinkContext\x12\x38\n\x0clinkImageURL\x18\x01 \x01(\x0b\x32\".InstamadilloCoreTypeLink.ImageUrl\x12\x18\n\x10linkPreviewTitle\x18\x02 \x01(\t\x12\x0f\n\x07linkURL\x18\x03 \x01(\t\x12\x13\n\x0blinkSummary\x18\x04 \x01(\t\x12\x1b\n\x13linkMusicPreviewURL\x18\x05 \x01(\t\x12(\n linkMusicPreviewCountriesAllowed\x18\x06 \x03(\t\x12\x42\n\x14linkPreviewThumbnail\x18\x07 \x01(\x0b\x32$.InstamadilloCoreTypeMedia.Thumbnail\x12\x17\n\x0flinkPreviewBody\x18\x08 \x01(\t\"6\n\x08ImageUrl\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x42\x34Z2go.mau.fi/whatsmeow/proto/instamadilloCoreTypeLink')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeLink.InstamadilloCoreTypeLink_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2go.mau.fi/whatsmeow/proto/instamadilloCoreTypeLink'
  _globals['_LINK']._serialized_start=144
  _globals['_LINK']._serialized_end=224
  _globals['_LINKCONTEXT']._serialized_start=227
  _globals['_LINKCONTEXT']._serialized_end=526
  _globals['_IMAGEURL']._serialized_start=528
  _globals['_IMAGEURL']._serialized_end=582
# @@protoc_insertion_point(module_scope)
