# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from instamadilloCoreTypeMedia import InstamadilloCoreTypeMedia_pb2 as instamadilloCoreTypeMedia_dot_InstamadilloCoreTypeMedia__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCinstamadilloCoreTypeCollection/InstamadilloCoreTypeCollection.proto\x12\x1eInstamadilloCoreTypeCollection\x1a\x39instamadilloCoreTypeMedia/InstamadilloCoreTypeMedia.proto\"K\n\nCollection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x05media\x18\x02 \x03(\x0b\x32 .InstamadilloCoreTypeMedia.MediaB:Z8go.mau.fi/whatsmeow/proto/instamadilloCoreTypeCollection')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloCoreTypeCollection.InstamadilloCoreTypeCollection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8go.mau.fi/whatsmeow/proto/instamadilloCoreTypeCollection'
  _globals['_COLLECTION']._serialized_start=162
  _globals['_COLLECTION']._serialized_end=237
# @@protoc_insertion_point(module_scope)
