# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: instamadilloXmaContentRef/InstamadilloXmaContentRef.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'instamadilloXmaContentRef/InstamadilloXmaContentRef.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9instamadilloXmaContentRef/InstamadilloXmaContentRef.proto\x12\x19InstamadilloXmaContentRef\"\x9c\x02\n\rXmaContentRef\x12<\n\nactionType\x18\x01 \x01(\x0e\x32(.InstamadilloXmaContentRef.XmaActionType\x12H\n\x0b\x63ontentType\x18\x02 \x01(\x0e\x32\x33.InstamadilloXmaContentRef.ReceiverFetchContentType\x12\x11\n\ttargetURL\x18\x03 \x01(\t\x12\x10\n\x08userName\x18\x04 \x01(\t\x12\x11\n\townerFbid\x18\x05 \x01(\t\x12K\n\x0b\x66\x65tchParams\x18\x06 \x01(\x0b\x32\x36.InstamadilloXmaContentRef.ReceiverFetchXmaFetchParams\"\xc1\x08\n\x1bReceiverFetchXmaFetchParams\x12U\n\x0fnoteFetchParams\x18\x01 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaNoteFetchParamsH\x00\x12W\n\x10storyFetchParams\x18\x02 \x01(\x0b\x32;.InstamadilloXmaContentRef.ReceiverFetchXmaStoryFetchParamsH\x00\x12[\n\x12profileFetchParams\x18\x03 \x01(\x0b\x32=.InstamadilloXmaContentRef.ReceiverFetchXmaProfileFetchParamsH\x00\x12U\n\x0f\x63lipFetchParams\x18\x04 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaClipFetchParamsH\x00\x12U\n\x0f\x66\x65\x65\x64\x46\x65tchParams\x18\x05 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaFeedFetchParamsH\x00\x12U\n\x0fliveFetchParams\x18\x06 \x01(\x0b\x32:.InstamadilloXmaContentRef.ReceiverFetchXmaLiveFetchParamsH\x00\x12[\n\x12\x63ommentFetchParams\x18\x07 \x01(\x0b\x32=.InstamadilloXmaContentRef.ReceiverFetchXmaCommentFetchParamsH\x00\x12g\n\x18locationShareFetchParams\x18\x08 \x01(\x0b\x32\x43.InstamadilloXmaContentRef.ReceiverFetchXmaLocationShareFetchParamsH\x00\x12\x61\n\x15reelsAudioFetchParams\x18\t \x01(\x0b\x32@.InstamadilloXmaContentRef.ReceiverFetchXmaReelsAudioFetchParamsH\x00\x12_\n\x14mediaNoteFetchParams\x18\n \x01(\x0b\x32?.InstamadilloXmaContentRef.ReceiverFetchXmaMediaNoteFetchParamsH\x00\x12g\n\x18socialContextFetchParams\x18\x0b \x01(\x0b\x32\x43.InstamadilloXmaContentRef.ReceiverFetchXmaSocialContextFetchParamsH\x00\x42\x1d\n\x1breceiverFetchXmaFetchParams\"3\n\x1fReceiverFetchXmaNoteFetchParams\x12\x10\n\x08noteIgid\x18\x01 \x01(\t\"E\n ReceiverFetchXmaStoryFetchParams\x12\x11\n\tstoryIgid\x18\x01 \x01(\t\x12\x0e\n\x06reelID\x18\x02 \x01(\t\"9\n\"ReceiverFetchXmaProfileFetchParams\x12\x13\n\x0bprofileIgid\x18\x01 \x01(\t\"4\n\x1fReceiverFetchXmaClipFetchParams\x12\x11\n\tmediaIgid\x18\x01 \x01(\t\"Y\n\x1fReceiverFetchXmaFeedFetchParams\x12\x11\n\tmediaIgid\x18\x01 \x01(\t\x12#\n\x1b\x63\x61rouselShareChildMediaIgid\x18\x02 \x01(\t\"3\n\x1fReceiverFetchXmaLiveFetchParams\x12\x10\n\x08liveIgid\x18\x01 \x01(\t\"9\n\"ReceiverFetchXmaCommentFetchParams\x12\x13\n\x0b\x63ommentFbid\x18\x01 \x01(\t\"@\n(ReceiverFetchXmaLocationShareFetchParams\x12\x14\n\x0clocationIgid\x18\x01 \x01(\t\":\n%ReceiverFetchXmaReelsAudioFetchParams\x12\x11\n\taudioIgid\x18\x01 \x01(\t\"\x8e\x01\n$ReceiverFetchXmaMediaNoteFetchParams\x12\x15\n\rmediaNoteIgid\x18\x01 \x01(\t\x12O\n\x0bmessageType\x18\x02 \x01(\x0e\x32:.InstamadilloXmaContentRef.MediaNoteFetchParamsMessageType\"=\n(ReceiverFetchXmaSocialContextFetchParams\x12\x11\n\tmediaIgid\x18\x01 \x01(\t*\x9e\x01\n\rXmaActionType\x12\x1f\n\x1bXMA_ACTION_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15XMA_ACTION_TYPE_SHARE\x10\x01\x12\x19\n\x15XMA_ACTION_TYPE_REPLY\x10\x02\x12\x19\n\x15XMA_ACTION_TYPE_REACT\x10\x03\x12\x1b\n\x17XMA_ACTION_TYPE_MENTION\x10\x04*\xc2\x04\n\x18ReceiverFetchContentType\x12+\n\'RECEIVER_FETCH_CONTENT_TYPE_UNSPECIFIED\x10\x00\x12$\n RECEIVER_FETCH_CONTENT_TYPE_NOTE\x10\x01\x12%\n!RECEIVER_FETCH_CONTENT_TYPE_STORY\x10\x02\x12\'\n#RECEIVER_FETCH_CONTENT_TYPE_PROFILE\x10\x03\x12$\n RECEIVER_FETCH_CONTENT_TYPE_CLIP\x10\x04\x12$\n RECEIVER_FETCH_CONTENT_TYPE_FEED\x10\x05\x12$\n RECEIVER_FETCH_CONTENT_TYPE_LIVE\x10\x06\x12\'\n#RECEIVER_FETCH_CONTENT_TYPE_COMMENT\x10\x07\x12.\n*RECEIVER_FETCH_CONTENT_TYPE_LOCATION_SHARE\x10\x08\x12+\n\'RECEIVER_FETCH_CONTENT_TYPE_REELS_AUDIO\x10\t\x12*\n&RECEIVER_FETCH_CONTENT_TYPE_MEDIA_NOTE\x10\n\x12/\n+RECEIVER_FETCH_CONTENT_TYPE_STORY_HIGHLIGHT\x10\x0b\x12.\n*RECEIVER_FETCH_CONTENT_TYPE_SOCIAL_CONTEXT\x10\x0c*\xb9\x01\n\x1fMediaNoteFetchParamsMessageType\x12\x34\n0MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x30\n,MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_MENTION\x10\x01\x12.\n*MEDIA_NOTE_FETCH_PARAMS_MESSAGE_TYPE_REPLY\x10\x02\x42\x35Z3go.mau.fi/whatsmeow/proto/instamadilloXmaContentRef')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'instamadilloXmaContentRef.InstamadilloXmaContentRef_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3go.mau.fi/whatsmeow/proto/instamadilloXmaContentRef'
  _globals['_XMAACTIONTYPE']._serialized_start=2242
  _globals['_XMAACTIONTYPE']._serialized_end=2400
  _globals['_RECEIVERFETCHCONTENTTYPE']._serialized_start=2403
  _globals['_RECEIVERFETCHCONTENTTYPE']._serialized_end=2981
  _globals['_MEDIANOTEFETCHPARAMSMESSAGETYPE']._serialized_start=2984
  _globals['_MEDIANOTEFETCHPARAMSMESSAGETYPE']._serialized_end=3169
  _globals['_XMACONTENTREF']._serialized_start=89
  _globals['_XMACONTENTREF']._serialized_end=373
  _globals['_RECEIVERFETCHXMAFETCHPARAMS']._serialized_start=376
  _globals['_RECEIVERFETCHXMAFETCHPARAMS']._serialized_end=1465
  _globals['_RECEIVERFETCHXMANOTEFETCHPARAMS']._serialized_start=1467
  _globals['_RECEIVERFETCHXMANOTEFETCHPARAMS']._serialized_end=1518
  _globals['_RECEIVERFETCHXMASTORYFETCHPARAMS']._serialized_start=1520
  _globals['_RECEIVERFETCHXMASTORYFETCHPARAMS']._serialized_end=1589
  _globals['_RECEIVERFETCHXMAPROFILEFETCHPARAMS']._serialized_start=1591
  _globals['_RECEIVERFETCHXMAPROFILEFETCHPARAMS']._serialized_end=1648
  _globals['_RECEIVERFETCHXMACLIPFETCHPARAMS']._serialized_start=1650
  _globals['_RECEIVERFETCHXMACLIPFETCHPARAMS']._serialized_end=1702
  _globals['_RECEIVERFETCHXMAFEEDFETCHPARAMS']._serialized_start=1704
  _globals['_RECEIVERFETCHXMAFEEDFETCHPARAMS']._serialized_end=1793
  _globals['_RECEIVERFETCHXMALIVEFETCHPARAMS']._serialized_start=1795
  _globals['_RECEIVERFETCHXMALIVEFETCHPARAMS']._serialized_end=1846
  _globals['_RECEIVERFETCHXMACOMMENTFETCHPARAMS']._serialized_start=1848
  _globals['_RECEIVERFETCHXMACOMMENTFETCHPARAMS']._serialized_end=1905
  _globals['_RECEIVERFETCHXMALOCATIONSHAREFETCHPARAMS']._serialized_start=1907
  _globals['_RECEIVERFETCHXMALOCATIONSHAREFETCHPARAMS']._serialized_end=1971
  _globals['_RECEIVERFETCHXMAREELSAUDIOFETCHPARAMS']._serialized_start=1973
  _globals['_RECEIVERFETCHXMAREELSAUDIOFETCHPARAMS']._serialized_end=2031
  _globals['_RECEIVERFETCHXMAMEDIANOTEFETCHPARAMS']._serialized_start=2034
  _globals['_RECEIVERFETCHXMAMEDIANOTEFETCHPARAMS']._serialized_end=2176
  _globals['_RECEIVERFETCHXMASOCIALCONTEXTFETCHPARAMS']._serialized_start=2178
  _globals['_RECEIVERFETCHXMASOCIALCONTEXTFETCHPARAMS']._serialized_end=2239
# @@protoc_insertion_point(module_scope)
